# -*- rpm-spec -*-

# This spec file assumes you are building on a Fedora or RHEL version
# that's still supported by the vendor. It may work on other distros
# or versions, but no effort will be made to ensure that going forward.
%define min_rhel 7
%define min_fedora 31

%if 0%{?fedora} >= %{min_fedora} || 0%{?rhel} >= %{min_rhel}
    %define supported_platform 1
%else
    %define supported_platform 0
%endif

# On RHEL 7 and older macro _vpath_builddir is not defined.
%if 0%{?rhel} && 0%{?rhel} <= 7
    %define _vpath_builddir %{_target_platform}
%endif

%define arches_qemu_kvm         %{ix86} x86_64 %{power64} %{arm} aarch64 s390x
%if 0%{?rhel}
    %define arches_qemu_kvm     x86_64 %{power64} aarch64 s390x
%endif

%define arches_64bit            x86_64 %{power64} aarch64 s390x riscv64
%define arches_x86              %{ix86} x86_64

%define arches_systemtap_64bit  %{arches_64bit}
%define arches_dmidecode        %{arches_x86}
%define arches_xen              %{arches_x86} aarch64
%define arches_vbox             %{arches_x86}
%define arches_ceph             %{arches_64bit}
%define arches_zfs              %{arches_x86} %{power64} %{arm}
%define arches_numactl          %{arches_x86} %{power64} aarch64
%define arches_numad            %{arches_x86} %{power64} aarch64

# The hypervisor drivers that run in libvirtd
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:1}

%ifarch %{arches_qemu_kvm}
    %define with_qemu_kvm      %{with_qemu}
%else
    %define with_qemu_kvm      0
%endif

%define with_qemu_tcg      %{with_qemu}

# RHEL disables TCG on all architectures
%if 0%{?rhel}
    %define with_qemu_tcg 0
%endif

%if ! %{with_qemu_tcg} && ! %{with_qemu_kvm}
    %define with_qemu 0
%endif

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:1}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd      0%{!?_without_storage_rbd:1}
%if 0%{?fedora}
    %define with_storage_sheepdog 0%{!?_without_storage_sheepdog:1}
%else
    %define with_storage_sheepdog 0
%endif

%define with_storage_gluster 0%{!?_without_storage_gluster:1}
%ifnarch %{arches_qemu_kvm}
    # gluster is only built where qemu driver is enabled on RHEL 8
    %if 0%{?rhel} >= 8
        %define with_storage_gluster 0
    %endif
%endif

# F25+ has zfs-fuse
%if 0%{?fedora}
    %define with_storage_zfs      0%{!?_without_storage_zfs:1}
%else
    %define with_storage_zfs      0
%endif

# We need a recent enough libiscsi (>= 1.18.0)
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:1}
%else
    %define with_storage_iscsi_direct 0
%endif

# Other optional features
%define with_numactl          0%{!?_without_numactl:1}

# A few optional bits off by default, we enable later
%define with_fuse             0
%define with_sanlock          0
%define with_numad            0
%define with_firewalld_zone   0
%define with_libssh2          0
%define with_wireshark        0
%define with_libssh           0
%define with_dmidecode        0

# Finally set the OS / architecture specific special cases

# Architecture-dependent features
%ifnarch %{arches_xen}
    %define with_libxl 0
%endif
%ifnarch %{arches_vbox}
    %define with_vbox 0
%endif
%ifnarch %{arches_numactl}
    %define with_numactl 0
%endif
%ifnarch %{arches_zfs}
    %define with_storage_zfs 0
%endif
%ifnarch %{arches_ceph}
    %define with_storage_rbd 0
%endif

# RHEL doesn't ship OpenVZ, VBox, PowerHypervisor,
# VMware, libxenlight (Xen 4.1 and newer),
# or HyperV.
%if 0%{?rhel}
    %define with_openvz 0
    %define with_vbox 0
    %define with_vmware 0
    %define with_libxl 0
    %define with_hyperv 0
    %define with_vz 0

    %if 0%{?rhel} > 7
        %define with_lxc 0
    %endif
%endif

%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_firewalld_zone 0%{!?_without_firewalld_zone:1}
%endif


# fuse is used to provide virtualized /proc for LXC
%if %{with_lxc}
    %define with_fuse      0%{!?_without_fuse:1}
%endif

# Enable sanlock library for lock management with QEMU
# Sanlock is available only on arches where kvm is available for RHEL
%if 0%{?fedora}
    %define with_sanlock 0%{!?_without_sanlock:1}
%endif
%if 0%{?rhel}
    %ifarch %{arches_qemu_kvm}
        %define with_sanlock 0%{!?_without_sanlock:1}
    %endif
%endif

# Enable libssh2 transport for new enough distros
%if 0%{?fedora}
    %define with_libssh2 0%{!?_without_libssh2:1}
%endif

# Enable wireshark plugins for all distros except RHEL-7
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_wireshark 0%{!?_without_wireshark:1}
    %define wireshark_plugindir %(pkg-config --variable plugindir wireshark)/epan
%endif

# Enable libssh transport for new enough distros
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_libssh 0%{!?_without_libssh:1}
%endif

%if %{with_qemu} || %{with_lxc}
# numad is used to manage the CPU and memory placement dynamically,
# it's not available on many non-x86 architectures.
    %ifarch %{arches_numad}
        %define with_numad    0%{!?_without_numad:1}
    %endif
%endif

%ifarch %{arches_dmidecode}
    %define with_dmidecode 0%{!?_without_dmidecode:1}
%endif

# Force QEMU to run as non-root
%define qemu_user  qemu
%define qemu_group  qemu


# RHEL releases provide stable tool chains and so it is safe to turn
# compiler warning into errors without being worried about frequent
# changes in reported warnings
%if 0%{?rhel}
    %define enable_werror -Dwerror=true
%else
    %define enable_werror -Dwerror=false
%endif

%if 0%{?rhel} == 7
    %define tls_priority "NORMAL"
%else
    %define tls_priority "@LIBVIRT,SYSTEM"
%endif


Summary: Library providing a simple virtualization API
Name: libvirt
Version: 7.0.0
Release: 14.6%{?dist}%{?extra_release}
License: LGPLv2+
URL: https://libvirt.org/

%if %(echo %{version} | grep -q "\.0$"; echo $?) == 1
    %define mainturl stable_updates/
%endif
Source: https://libvirt.org/sources/%{?mainturl}libvirt-%{version}.tar.xz
Source1: symlinks

Patch1: libvirt-RHEL-Hack-around-changed-Broadwell-Haswell-CPUs.patch
Patch2: libvirt-RHEL-Add-rhel-machine-types-to-qemuDomainMachineNeedsFDC.patch
Patch3: libvirt-RHEL-Fix-virConnectGetMaxVcpus-output.patch
Patch4: libvirt-RHEL-qemu-Add-ability-to-set-sgio-values-for-hostdev.patch
Patch5: libvirt-RHEL-qemu-Add-check-for-unpriv-sgio-for-SCSI-generic-host-device.patch
Patch6: libvirt-RHEL-qemu-Alter-val-usage-in-qemuSetUnprivSGIO.patch
Patch7: libvirt-RHEL-qemu-Alter-qemuSetUnprivSGIO-hostdev-shareable-logic.patch
Patch8: libvirt-RHEL-qemu-Fix-logic-error-in-qemuSetUnprivSGIO.patch
Patch9: libvirt-RHEL-qemu-Fix-crash-trying-to-use-iSCSI-hostdev.patch
Patch10: libvirt-RHEL-virscsi-Check-device-type-before-getting-it-s-dev-node-name.patch
Patch11: libvirt-RHEL-virscsi-Support-TAPEs-in-virSCSIDeviceGetDevName.patch
Patch12: libvirt-RHEL-virscsi-Introduce-and-use-virSCSIDeviceGetUnprivSGIOSysfsPath.patch
Patch13: libvirt-RHEL-virutil-Accept-non-block-devices-in-virGetDeviceID.patch
Patch14: libvirt-RHEL-qemuSetUnprivSGIO-Actually-use-calculated-sysfs_path-to-set-unpriv_sgio.patch
Patch15: libvirt-RHEL-qemuCheckUnprivSGIO-use-sysfs_path-to-get-unpriv_sgio.patch
Patch16: libvirt-RHEL-Enable-usage-of-x-blockdev-reopen.patch
Patch17: libvirt-meson-Fix-build-with-Dtest_coverage-true.patch
Patch18: libvirt-qemu-don-t-set-interface-MTU-when-managed-no.patch
Patch19: libvirt-network-explicitly-set-the-MTU-of-the-bridge-device.patch
Patch20: libvirt-util-add-virNetDevGetPhysPortName.patch
Patch21: libvirt-util-Add-phys_port_name-support-on-virPCIGetNetName.patch
Patch22: libvirt-cpu_map-Remove-intel-pt-from-x86-CPU-models.patch
Patch23: libvirt-qemu-Avoid-crash-in-qemuStateShutdownPrepare-and-qemuStateShutdownWait.patch
Patch24: libvirt-qemu-fix-release-of-virDomainObjPtr-in-SSH-key-APIs.patch
Patch25: libvirt-qemu_capabilities-Introduce-QEMU_CAPS_X_USE_CANONICAL_PATH_FOR_RAMBLOCK_ID.patch
Patch26: libvirt-qemu-Do-not-Use-canonical-path-for-system-memory.patch
Patch27: libvirt-qemu-match-alias-when-looking-for-proper-interface-to-detach.patch
Patch28: libvirt-conf-make-teaming-info-an-official-type.patch
Patch29: libvirt-conf-use-virDomainNetTeamingInfoPtr-instead-of-virDomainNetTeamingInfo.patch
Patch30: libvirt-conf-separate-Parse-Format-functions-for-virDomainNetTeamingInfo.patch
Patch31: libvirt-schema-separate-teaming-element-definition-from-interface-element.patch
Patch32: libvirt-conf-parse-format-teaming-element-in-plain-hostdev.patch
Patch33: libvirt-qemu-plug-teaming-config-from-hostdev-into-qemu-commandline.patch
Patch34: libvirt-qemu_hotplug-Don-t-dereference-NULL-pointer-newb-in-qemuDomainChangeNet.patch
Patch35: libvirt-qemu-Drop-needless-check-in-virDomainFSInfoFormat.patch
Patch36: libvirt-qemu-Move-qemuAgentFSInfo-array-free-into-qemuDomainGetFSInfo.patch
Patch37: libvirt-qemu-Bring-if-outside-from-loop-in-virDomainFSInfoFormat.patch
Patch38: libvirt-qemu-Don-t-lie-about-ndevAlias-when-translating-FSInfo.patch
Patch39: libvirt-conf-Move-virDomainCheckVirtioOptions-into-domain_validate.c.patch
Patch40: libvirt-conf-Improve-virDomainVirtioOptionsCheckABIStability.patch
Patch41: libvirt-qemu-Add-virtio-related-options-to-vsock.patch
Patch42: libvirt-virsystemd-export-virSystemdHasMachined.patch
Patch43: libvirt-virsystemd-introduce-virSystemdGetMachineByPID.patch
Patch44: libvirt-virsystemd-introduce-virSystemdGetMachineUnitByPID.patch
Patch45: libvirt-vircgroup-use-DBus-call-to-systemd-for-some-APIs.patch
Patch46: libvirt-vircgroupv1-refactor-virCgroupV1DetectPlacement.patch
Patch47: libvirt-vircgroupv2-move-task-into-cgroup-before-enabling-controllers.patch
Patch48: libvirt-vircgroup-introduce-virCgroupV1Exists-and-virCgroupV2Exists.patch
Patch49: libvirt-vircgroup-introduce-nested-cgroup-to-properly-work-with-systemd.patch
Patch50: libvirt-tests-add-cgroup-nested-tests.patch
Patch51: libvirt-vircgroup-correctly-free-nested-virCgroupPtr.patch
Patch52: libvirt-src-add-missing-virstoragefile.h-includes.patch
Patch53: libvirt-virstoragefile-properly-include-virstoragefile.h-header.patch
Patch54: libvirt-virstoragefile-change-virStorageSource-drv-to-void-pointer.patch
Patch55: libvirt-storage-move-storage-file-sources-to-separate-directory.patch
Patch56: libvirt-util-move-virStorageSourceFindByNodeName-into-qemu_domain.patch
Patch57: libvirt-util-extract-storage-file-probe-code-into-virtstoragefileprobe.c.patch
Patch58: libvirt-util-extract-virStorageFile-code-into-storage_source.patch
Patch59: libvirt-util-move-virStorageFileBackend-code-into-storage_file.patch
Patch60: libvirt-util-move-virStorageFileProbe-code-into-storage_file.patch
Patch61: libvirt-util-move-virStorageSource-code-into-conf.patch
Patch62: libvirt-util-move-virStorageEncryption-code-into-conf.patch
Patch63: libvirt-storage_source-use-virStorageSource-prefix-for-all-functions.patch
Patch64: libvirt-conf-rename-virDomainCheckVirtioOptions.patch
Patch65: libvirt-qemu_alias-introduce-qemuDomainGetVhostUserAlias-helper.patch
Patch66: libvirt-qemu_validate-move-and-refactor-qemuValidateDomainDefVirtioFSSharedMemory.patch
Patch67: libvirt-docs-introduces-new-vhostuser-disk-type.patch
Patch68: libvirt-conf-implement-support-for-vhostuser-disk.patch
Patch69: libvirt-qemu_capabilities-introduce-vhost-user-blk-capability.patch
Patch70: libvirt-qemu-implement-vhost-user-blk-support.patch
Patch71: libvirt-conf-allow-virtio-driver-attributes-for-vhostuser-disk.patch
Patch72: libvirt-virStorageSourceClear-Unref-vhostuser.patch
Patch73: libvirt-qemu-Fix-libvirt-hang-due-to-early-TPM-device-stop.patch
Patch74: libvirt-api-Discourage-use-of-VIR_DOMAIN_SNAPSHOT_CREATE_QUIESCE.patch
Patch75: libvirt-qemuSnapshotCreateActiveExternal-Don-t-thaw-filesystems-when-freeze-fails.patch
Patch76: libvirt-qemuSnapshotFSFreeze-Don-t-return-2.patch
Patch77: libvirt-qemu-capabilities-Introduce-QEMU_CAPS_MIGRATION_PARAM_BLOCK_BITMAP_MAPPING.patch
Patch78: libvirt-qemu-Probe-whether-an-image-is-qcow2-v2-from-query-named-block-nodes.patch
Patch79: libvirt-qemu-migration-Create-qcow2-v3-images-for-VIR_MIGRATE_NON_SHARED_DISK.patch
Patch80: libvirt-qemu-monitor-Introduce-qemuMonitorBitmapRemove.patch
Patch81: libvirt-qemu-blockjob-Use-qemuMonitorBitmapRemove-for-single-bitmap-removal.patch
Patch82: libvirt-qemu-migration_params-Add-infrastructure-for-dirty-bitmaps-migration-feature.patch
Patch83: libvirt-qemu-migration_cookie-Add-XML-handling-for-setting-up-bitmap-migration.patch
Patch84: libvirt-qemu-migration_cookie-Add-helpers-for-transforming-the-cookie-into-migration-params.patch
Patch85: libvirt-qemu-domain-Store-list-of-temporary-bitmaps-for-migration-in-status-XML.patch
Patch86: libvirt-qemu-migration-Clean-up-temporary-bitmaps-when-cancelling-a-migration.patch
Patch87: libvirt-qemu-migration-Migrate-block-dirty-bitmaps-corresponding-to-checkpoints.patch
Patch88: libvirt-qemu-capabilities-Enable-QEMU_CAPS_INCREMENTAL_BACKUP.patch
Patch89: libvirt-qemu-allow-migration-of-generic-hostdev-with-teaming.patch
Patch90: libvirt-docs-fix-bad-cut-paste-in-teaming-example.patch
Patch91: libvirt-qemu_domainjob-Make-copy-of-owner-API.patch
Patch92: libvirt-storageBackendProbeTarget-Check-return-value-of-virStorageSourceNewFromBacking.patch
Patch93: libvirt-qemuBackupJobTerminate-Move-cleanup-of-temp-files-earlier.patch
Patch94: libvirt-qemuBackupJobTerminate-Don-t-calculate-backup-job-stats-if-VM-isn-t-active.patch
Patch95: libvirt-cpumap-Add-support-for-ibrs-CPU-feature.patch
Patch96: libvirt-cpumap-Add-support-for-svme-addr-check-CPU-feature.patch
Patch97: libvirt-cpu_map-Add-EPYC-Milan-x86-CPU-model.patch
Patch98: libvirt-cpu_map-Install-x86_EPYC-Milan.xml.patch
Patch99: libvirt-cpu_map-Fix-spelling-of-svme-addr-chk-feature.patch
Patch100: libvirt-domain_validate-use-defines-for-cpu-period-and-quota-limits.patch
Patch101: libvirt-docs-use-proper-cpu-quota-value-in-our-documentation.patch
Patch102: libvirt-vircgroup-enforce-range-limit-for-cpu.shares.patch
Patch103: libvirt-cgroup-use-virCgroupSetCpuShares-instead-of-virCgroupSetupCpuShares.patch
Patch104: libvirt-vircgroup-drop-unused-function-virCgroupSetupCpuShares.patch
Patch105: libvirt-virSystemdCreateMachine-Use-proper-format-string-for-uint64_t-when-constructing-gvariant.patch
Patch106: libvirt-virsystemdtest-Call-at-least-one-virSystemdCreateMachine-with-maxthreads-0.patch
Patch107: libvirt-backup-Store-apiFlags-in-private-section-of-virDomainBackupDef.patch
Patch108: libvirt-qemuBackupJobTerminate-Fix-job-termination-for-inactive-VMs.patch
Patch109: libvirt-virLockSpaceNewPostExecRestart-Fix-out-of-bounds-array-access.patch
Patch110: libvirt-virnetdaemon-Introduce-virNetDaemonQuitExecRestart.patch
Patch111: libvirt-virtlo-g-ck-d-Fix-exec-restart.patch
Patch112: libvirt-util-Move-glib-event-loop-workaround-to-glibcompat.patch
Patch113: libvirt-glib-Use-safe-glib-event-workaround-in-other-event-loops.patch
Patch114: libvirt-src-ensure-GSource-background-unref-happens-in-correct-event-loop.patch
Patch115: libvirt-qemu_driver-fix-setting-vcpu_quota-if-not-all-vCPUs-are-online.patch
Patch116: libvirt-qemu-backup-Restore-security-label-on-backup-disk-store-image-on-VM-termination.patch
Patch117: libvirt-qemuCheckpointDiscardBitmaps-Refuse-to-delete-checkpoint-with-NULL-bitmap-name.patch
Patch118: libvirt-virDomainCheckpointRedefinePrep-Assign-default-bitmap-names-when-domain-XML-is-missing.patch
Patch119: libvirt-util-Document-limit-related-functions.patch
Patch120: libvirt-util-Simplify-stubs.patch
Patch121: libvirt-util-Always-pass-a-pid-to-virProcessSetMax.patch
Patch122: libvirt-util-Introduce-virProcess-Get-Set-Limit.patch
Patch123: libvirt-qemu-Make-some-minor-tweaks.patch
Patch124: libvirt-qemu-Set-all-limits-at-the-same-time.patch
Patch125: libvirt-util-Have-virCommand-remember-whether-limits-are-set.patch
Patch126: libvirt-qemu-Set-limits-only-when-explicitly-asked-to-do-so.patch
Patch127: libvirt-util-Don-t-special-case-setting-a-limit-to-zero.patch
Patch128: libvirt-conf-Rename-original_memlock-originalMemlock.patch
Patch129: libvirt-tests-Mock-virProcessGetMaxMemLock.patch
Patch130: libvirt-util-Try-to-get-limits-from-proc.patch
Patch131: libvirt-qemu-Don-t-ignore-virProcessGetMaxMemLock-errors.patch
Patch132: libvirt-qemu-Refactor-qemuDomainAdjustMaxMemLock.patch
Patch133: libvirt-qemu-Only-raise-memlock-limit-if-necessary.patch
Patch134: libvirt-Revert-remote-Add-libvirtd-dependency-to-virt-guest-shutdown.target.patch
Patch135: libvirt-conf-Fix-heap-corruption-when-hot-adding-a-lease.patch
Patch136: libvirt-qemu-blockjob-Transition-into-ready-state-only-from-expected-states.patch
Patch137: libvirt-storage-add-support-for-QCOW2-cluster_size-option.patch
Patch138: libvirt-storage_file-add-support-to-probe-cluster_size-from-QCOW2-images.patch
Patch139: libvirt-qemu-Signal-domain-condition-in-qemuProcessStop-a-bit-later.patch
Patch140: libvirt-security-fix-SELinux-label-generation-logic.patch
Patch141: libvirt-storage_driver-Unlock-object-on-ACL-fail-in-storagePoolLookupByTargetPath.patch
Patch142: libvirt-util-directly-query-KVM-for-TSC-scaling-support.patch
Patch143: libvirt-qemu-Check-if-unpriv_sgio-is-already-set-before-trying-to-set-it.patch
Patch144: libvirt-qemu_validate-Allow-kvm-hint-dedicated-on-non-passthrough-VMs.patch

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-config-network = %{version}-%{release}
Requires: libvirt-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_lxc}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
%endif
%if %{with_qemu}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
%endif
# We had UML driver, but we've removed it.
Obsoletes: libvirt-daemon-driver-uml <= 5.0.0
Obsoletes: libvirt-daemon-uml <= 5.0.0
%if %{with_vbox}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-client = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
BuildRequires: gettext-devel
%if 0%{?rhel} == 7
BuildRequires: python36-docutils
%else
BuildRequires: python3-docutils
%endif
BuildRequires: gcc
BuildRequires: meson >= 0.54.0
BuildRequires: ninja-build
BuildRequires: make
BuildRequires: git
%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: perl-interpreter
%else
BuildRequires: perl
%endif
%if 0%{?rhel} > 7
BuildRequires: python3-devel
%else
BuildRequires: python3
%endif
BuildRequires: systemd-units
%if %{with_libxl}
BuildRequires: xen-devel
%endif
BuildRequires: glib2-devel >= 2.48
BuildRequires: libxml2-devel
BuildRequires: libxslt
BuildRequires: readline-devel
BuildRequires: bash-completion >= 2.0
BuildRequires: gettext
BuildRequires: libtasn1-devel
BuildRequires: gnutls-devel
BuildRequires: libattr-devel
# For pool-build probing for existing pools
BuildRequires: libblkid-devel >= 2.17
# for augparse, optionally used in testing
BuildRequires: augeas
BuildRequires: systemd-devel >= 185
BuildRequires: libpciaccess-devel >= 0.10.9
BuildRequires: yajl-devel
%if %{with_sanlock}
BuildRequires: sanlock-devel >= 2.4
%endif
BuildRequires: libpcap-devel >= 1.5.0
BuildRequires: libnl3-devel
BuildRequires: libselinux-devel
BuildRequires: dnsmasq >= 2.41
BuildRequires: iptables
BuildRequires: radvd
BuildRequires: ebtables
BuildRequires: module-init-tools
BuildRequires: cyrus-sasl-devel
BuildRequires: polkit >= 0.112
# For mount/umount in FS driver
BuildRequires: util-linux
%if %{with_qemu}
# For managing ACLs
BuildRequires: libacl-devel
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%endif
# For LVM drivers
BuildRequires: lvm2
# For pool type=iscsi
BuildRequires: iscsi-initiator-utils
%if %{with_storage_iscsi_direct}
# For pool type=iscsi-direct
BuildRequires: libiscsi-devel
%endif
# For disk driver
BuildRequires: parted-devel
# For Multipath support
BuildRequires: device-mapper-devel
# For XFS reflink clone support
BuildRequires: xfsprogs-devel
%if %{with_storage_rbd}
    %if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: librados-devel
BuildRequires: librbd-devel
    %else
BuildRequires: librados2-devel
BuildRequires: librbd1-devel
    %endif
%endif
%if %{with_storage_gluster}
BuildRequires: glusterfs-api-devel >= 3.4.1
BuildRequires: glusterfs-devel >= 3.4.1
%endif
%if %{with_storage_sheepdog}
BuildRequires: sheepdog
%endif
%if %{with_storage_zfs}
# Support any conforming implementation of zfs. On stock Fedora
# this is zfs-fuse, but could be zfsonlinux upstream RPMs
BuildRequires: /sbin/zfs
BuildRequires: /sbin/zpool
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-ng-devel >= 0.5.0
%if %{with_fuse}
BuildRequires: fuse-devel >= 2.8.6
%endif
%if %{with_libssh2}
BuildRequires: libssh2-devel >= 1.3.0
%endif

BuildRequires: netcf-devel >= 0.2.2
%if %{with_esx}
BuildRequires: libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires: libwsman-devel >= 2.6.3
%endif
BuildRequires: audit-libs-devel
# we need /usr/sbin/dtrace
BuildRequires: systemtap-sdt-devel

# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils

# Fedora build root suckage
BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires: scrub

%if %{with_numad}
BuildRequires: numad
%endif

%if %{with_wireshark}
BuildRequires: wireshark-devel
%endif

%if %{with_libssh}
BuildRequires: libssh-devel >= 0.7.0
%endif

# On RHEL-7 rpcgen is still part of glibc-common package
%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: rpcgen
%endif

BuildRequires: libtirpc-devel

# Needed for the firewalld_reload macro
%if %{with_firewalld_zone}
BuildRequires: firewalld-filesystem
%endif

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes). The main package includes
the libvirtd server exporting the virtualization support.

%package docs
Summary: API reference and website documentation

%description docs
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary: Server side daemon and supporting files for libvirt library

# All runtime requirements for the libvirt package (runtime requrements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs are in a subpackage
Requires: %{name}-libs = %{version}-%{release}

# (client invokes 'nc' against the UNIX socket on the server)
Requires: /usr/bin/nc

# for modprobe of pci devices
Requires: module-init-tools

# for /sbin/ip & /sbin/tc
Requires: iproute
# tc is provided by iproute-tc since at least Fedora 26
%if 0%{?fedora} || 0%{?rhel} > 7
Requires: iproute-tc
%endif

Requires: polkit >= 0.112
%if %{with_dmidecode}
# For virConnectGetSysinfo
Requires: dmidecode
%endif
# For service management
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
%if %{with_numad}
Requires: numad
%endif
# libvirtd depends on 'messagebus' service
Requires: dbus
# For uid creation during pre
Requires(pre): shadow-utils

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-config-network
Summary: Default configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary: Network filter configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for cleaning guest traffic

%package daemon-driver-network
Summary: Network driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: dnsmasq >= 2.41
Requires: radvd
Requires: iptables

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.


%package daemon-driver-nwfilter
Summary: Nwfilter driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iptables
Requires: ebtables

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities


%package daemon-driver-nodedev
Summary: Nodedev driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# needed for device enumeration
Requires: systemd >= 185
# For managing persistent mediated devices
%if 0%{?fedora} || 0%{?rhel} > 7
Requires: mdevctl
%endif

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.


%package daemon-driver-interface
Summary: Interface driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: netcf-libs >= 0.2.2

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcf library


%package daemon-driver-secret
Summary: Secret driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.

%package daemon-driver-storage-core
Summary: Storage driver plugin including base backends for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: nfs-utils
# For mkfs
Requires: util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires: /usr/bin/qemu-img
%endif
%if !%{with_storage_rbd}
Obsoletes: libvirt-daemon-driver-storage-rbd < %{version}-%{release}
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%package daemon-driver-storage-logical
Summary: Storage driver plugin for lvm volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.


%package daemon-driver-storage-disk
Summary: Storage driver plugin for disk
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: parted
Requires: device-mapper

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.


%package daemon-driver-storage-scsi
Summary: Storage driver plugin for local scsi devices
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.


%package daemon-driver-storage-iscsi
Summary: Storage driver plugin for iscsi
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iscsi-initiator-utils

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.


%if %{with_storage_iscsi_direct}
%package daemon-driver-storage-iscsi-direct
Summary: Storage driver plugin for iscsi-direct
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: libiscsi

%description daemon-driver-storage-iscsi-direct
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using libiscsi direct connection.
%endif


%package daemon-driver-storage-mpath
Summary: Storage driver plugin for multipath volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.


%if %{with_storage_gluster}
%package daemon-driver-storage-gluster
Summary: Storage driver plugin for gluster
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
    %if 0%{?fedora}
Requires: glusterfs-client >= 2.0.1
    %endif
    %if (0%{?fedora} || 0%{?with_storage_gluster})
Requires: /usr/sbin/gluster
    %endif

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.
%endif


%if %{with_storage_rbd}
%package daemon-driver-storage-rbd
Summary: Storage driver plugin for rbd
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.
%endif


%if %{with_storage_sheepdog}
%package daemon-driver-storage-sheepdog
Summary: Storage driver plugin for sheepdog
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: sheepdog

%description daemon-driver-storage-sheepdog
The storage driver backend adding implementation of the storage APIs for
sheepdog volumes using.
%endif


%if %{with_storage_zfs}
%package daemon-driver-storage-zfs
Summary: Storage driver plugin for ZFS
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# Support any conforming implementation of zfs
Requires: /sbin/zfs
Requires: /sbin/zpool

%description daemon-driver-storage-zfs
The storage driver backend adding implementation of the storage APIs for
ZFS volumes.
%endif


%package daemon-driver-storage
Summary: Storage driver plugin including all backends for the libvirtd daemon
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-disk = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-logical = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-scsi = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-iscsi = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-mpath = %{version}-%{release}
%if %{with_storage_iscsi_direct}
Requires: libvirt-daemon-driver-storage-iscsi-direct = %{version}-%{release}
%endif
%if %{with_storage_gluster}
Requires: libvirt-daemon-driver-storage-gluster = %{version}-%{release}
%endif
%if %{with_storage_rbd}
Requires: libvirt-daemon-driver-storage-rbd = %{version}-%{release}
%endif
%if %{with_storage_sheepdog}
Requires: libvirt-daemon-driver-storage-sheepdog = %{version}-%{release}
%endif
%if %{with_storage_zfs}
Requires: libvirt-daemon-driver-storage-zfs = %{version}-%{release}
%endif

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.


%if %{with_qemu}
%package daemon-driver-qemu
Summary: QEMU driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: /usr/bin/qemu-img
# For image compression
Requires: gzip
Requires: bzip2
Requires: lzop
Requires: xz
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: swtpm-tools
    %endif

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
QEMU
%endif


%if %{with_lxc}
%package daemon-driver-lxc
Summary: LXC driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires: libvirt-daemon-driver-network = %{version}-%{release}
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif


%if %{with_vbox}
%package daemon-driver-vbox
Summary: VirtualBox driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif


%if %{with_libxl}
%package daemon-driver-libxl
Summary: Libxl driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Obsoletes: libvirt-daemon-driver-xen < 4.3.0

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Libxl
%endif



%if %{with_qemu_tcg}
%package daemon-qemu
Summary: Server side daemon & driver required to run QEMU guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU TCG emulators
%endif


%if %{with_qemu_kvm}
%package daemon-kvm
Summary: Server side daemon & driver required to run KVM guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu-kvm

%description daemon-kvm
Server side daemon and driver required to manage the virtualization
capabilities of the KVM hypervisor
%endif


%if %{with_lxc}
%package daemon-lxc
Summary: Server side daemon & driver required to run LXC guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif


%if %{with_libxl}
%package daemon-xen
Summary: Server side daemon & driver required to run XEN guests

Requires: libvirt-daemon = %{version}-%{release}
    %if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}
%package daemon-vbox
Summary: Server side daemon & driver required to run VirtualBox guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%package client
Summary: Client side utilities of the libvirt library
Requires: %{name}-libs = %{version}-%{release}
# Needed by /usr/libexec/libvirt-guests.sh script.
Requires: gettext
# Needed by virt-pki-validate script.
Requires: gnutls-utils
Requires: %{name}-bash-completion = %{version}-%{release}

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package libs
Summary: Client side libraries
# So remote clients can access libvirt over SSH tunnel
Requires: cyrus-sasl
# Needed by default sasl.conf - no onerous extra deps, since
# 100's of other things on a system already pull in krb5-libs
Requires: cyrus-sasl-gssapi

%description libs
Shared libraries for accessing the libvirt daemon.

%package admin
Summary: Set of tools to control libvirt daemon
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-bash-completion = %{version}-%{release}

%description admin
The client side utilities to control the libvirt daemon.

%package bash-completion
Summary: Bash completion script

%description bash-completion
Bash completion script stub.

%if %{with_wireshark}
%package wireshark
Summary: Wireshark dissector plugin for libvirt RPC transactions
Requires: wireshark
Requires: %{name}-libs = %{version}-%{release}

%description wireshark
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%if %{with_lxc}
%package login-shell
Summary: Login shell for connecting users to an LXC container
Requires: %{name}-libs = %{version}-%{release}

%description login-shell
Provides the set-uid virt-login-shell binary that is used to
connect a user to an LXC container when they login, by switching
namespaces.
%endif

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: pkgconfig

%description devel
Include header files & development libraries for the libvirt C library.

%if %{with_sanlock}
%package lock-sanlock
Summary: Sanlock lock manager plugin for QEMU driver
Requires: sanlock >= 2.4
#for virt-sanlock-cleanup require augeas
Requires: augeas
Requires: %{name}-daemon = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU
driver
%endif

%package nss
Summary: Libvirt plugin for Name Service Switch
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description nss
Libvirt plugin for NSS for translating domain names into IP addresses.


%prep

%autosetup -S git_am -N

# "make dist" replaces all symlinks with a copy of the linked files;
# we need to replace all of them with the original symlinks
echo "Restoring symlinks"
while read lnk target; do
    if [ -e $lnk ]; then
        rm -rf $lnk
        ln -s $target $lnk
    fi
done <%{_sourcedir}/symlinks || exit 1
git add .
git commit -q -a --allow-empty --author 'rpm-build <rpm-build>' -m symlinks


git config gc.auto 0

%autopatch

%build

%if 0%{?fedora} == 34
    # binutils change in F34 broke linking of tests
    # https://bugzilla.redhat.com/show_bug.cgi?id=1889763
    %define _lto_cflags %{nil}
%endif

%if ! %{supported_platform}
echo "This RPM requires either Fedora >= %{min_fedora} or RHEL >= %{min_rhel}"
exit 1
%endif

%if %{with_qemu}
    %define arg_qemu -Ddriver_qemu=enabled
%else
    %define arg_qemu -Ddriver_qemu=disabled
%endif

%if %{with_openvz}
    %define arg_openvz -Ddriver_openvz=enabled
%else
    %define arg_openvz -Ddriver_openvz=disabled
%endif

%if %{with_lxc}
    %define arg_lxc -Ddriver_lxc=enabled
    %define arg_login_shell -Dlogin_shell=enabled
%else
    %define arg_lxc -Ddriver_lxc=disabled
    %define arg_login_shell -Dlogin_shell=disabled
%endif

%if %{with_vbox}
    %define arg_vbox -Ddriver_vbox=enabled
%else
    %define arg_vbox -Ddriver_vbox=disabled
%endif

%if %{with_libxl}
    %define arg_libxl -Ddriver_libxl=enabled
%else
    %define arg_libxl -Ddriver_libxl=disabled
%endif

%if %{with_esx}
    %define arg_esx -Ddriver_esx=enabled -Dcurl=enabled
%else
    %define arg_esx -Ddriver_esx=disabled -Dcurl=disabled
%endif

%if %{with_hyperv}
    %define arg_hyperv -Ddriver_hyperv=enabled -Dopenwsman=enabled
%else
    %define arg_hyperv -Ddriver_hyperv=disabled -Dopenwsman=disabled
%endif

%if %{with_vmware}
    %define arg_vmware -Ddriver_vmware=enabled
%else
    %define arg_vmware -Ddriver_vmware=disabled
%endif

%if %{with_storage_rbd}
    %define arg_storage_rbd -Dstorage_rbd=enabled
%else
    %define arg_storage_rbd -Dstorage_rbd=disabled
%endif

%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog -Dstorage_sheepdog=enabled
%else
    %define arg_storage_sheepdog -Dstorage_sheepdog=disabled
%endif

%if %{with_storage_gluster}
    %define arg_storage_gluster -Dstorage_gluster=enabled -Dglusterfs=enabled
%else
    %define arg_storage_gluster -Dstorage_gluster=disabled -Dglusterfs=disabled
%endif

%if %{with_storage_zfs}
    %define arg_storage_zfs -Dstorage_zfs=enabled
%else
    %define arg_storage_zfs -Dstorage_zfs=disabled
%endif

%if %{with_numactl}
    %define arg_numactl -Dnumactl=enabled
%else
    %define arg_numactl -Dnumactl=disabled
%endif

%if %{with_numad}
    %define arg_numad -Dnumad=enabled
%else
    %define arg_numad -Dnumad=disabled
%endif

%if %{with_fuse}
    %define arg_fuse -Dfuse=enabled
%else
    %define arg_fuse -Dfuse=disabled
%endif

%if %{with_sanlock}
    %define arg_sanlock -Dsanlock=enabled
%else
    %define arg_sanlock -Dsanlock=disabled
%endif

%if %{with_firewalld_zone}
    %define arg_firewalld_zone -Dfirewalld_zone=enabled
%else
    %define arg_firewalld_zone -Dfirewalld_zone=disabled
%endif

%if %{with_wireshark}
    %define arg_wireshark -Dwireshark_dissector=enabled
%else
    %define arg_wireshark -Dwireshark_dissector=disabled
%endif

%if %{with_storage_iscsi_direct}
    %define arg_storage_iscsi_direct -Dstorage_iscsi_direct=enabled -Dlibiscsi=enabled
%else
    %define arg_storage_iscsi_direct -Dstorage_iscsi_direct=disabled -Dlibiscsi=disabled
%endif

%if %{with_libssh}
    %define arg_libssh -Dlibssh=enabled
%else
    %define arg_libssh -Dlibssh=disabled
%endif

%if %{with_libssh2}
    %define arg_libssh2 -Dlibssh2=enabled
%else
    %define arg_libssh2 -Dlibssh2=disabled
%endif

%define when  %(date +"%%F-%%T")
%define where %(hostname)
%define who   %{?packager}%{!?packager:Unknown}
%define arg_packager -Dpackager="%{who}, %{when}, %{where}"
%define arg_packager_version -Dpackager_version="%{release}"

%define arg_selinux_mount -Dselinux_mount="/sys/fs/selinux"

# place macros above and build commands below this comment

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%meson \
           -Drunstatedir=%{_rundir} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           -Dsasl=enabled \
           -Dpolkit=enabled \
           -Ddriver_libvirtd=enabled \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           -Ddriver_vz=disabled \
           -Ddriver_bhyve=disabled \
           -Dremote_default_mode=legacy \
           -Ddriver_interface=enabled \
           -Ddriver_network=enabled \
           -Dstorage_fs=enabled \
           -Dstorage_lvm=enabled \
           -Dstorage_iscsi=enabled \
           %{?arg_storage_iscsi_direct} \
           -Dstorage_scsi=enabled \
           -Dstorage_disk=enabled \
           -Dstorage_mpath=enabled \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           %{?arg_storage_zfs} \
           -Dstorage_vstorage=disabled \
           %{?arg_numactl} \
           %{?arg_numad} \
           -Dcapng=enabled \
           %{?arg_fuse} \
           -Dnetcf=enabled \
           -Dselinux=enabled \
           %{?arg_selinux_mount} \
           -Dapparmor=disabled \
           -Dsecdriver_apparmor=disabled \
           -Dudev=enabled \
           -Dyajl=enabled \
           %{?arg_sanlock} \
           -Dlibpcap=enabled \
           -Dlibnl=enabled \
           -Daudit=enabled \
           -Ddtrace=enabled \
           -Dfirewalld=enabled \
           %{?arg_firewalld_zone} \
           %{?arg_wireshark} \
           %{?arg_libssh} \
           %{?arg_libssh2} \
           -Dpm_utils=disabled \
           -Dnss=enabled \
           %{arg_packager} \
           %{arg_packager_version} \
           -Dqemu_user=%{qemu_user} \
           -Dqemu_group=%{qemu_group} \
           -Dtls_priority=%{tls_priority} \
           %{?enable_werror} \
           -Dexpensive_tests=enabled \
           -Dinit_script=systemd \
           -Ddocs=enabled \
           -Dtests=enabled \
           -Drpath=disabled \
           %{?arg_login_shell}

%meson_build

%install
rm -fr %{buildroot}

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%meson_install

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.a
%if %{with_wireshark}
rm -f $RPM_BUILD_ROOT%{wireshark_plugindir}/libvirt.la
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
# libvirt saves this file with mode 0600
chmod 0600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml

# nwfilter files are installed in /usr/share/libvirt and copied to /etc in %post
# to avoid verification errors on changed files in /etc
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
cp -a $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml \
    $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml

%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_sanlock}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_libxl}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/libxl.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif

# Copied into libvirt-docs subpackage eventually
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt libvirt-docs

%ifarch %{arches_systemtap_64bit}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes-64.stp

    %if %{with_qemu}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
    %endif
%endif

%check
VIR_TEST_DEBUG=1 %meson_test --no-suite syntax-check

%post libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%postun libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%pre daemon
# 'libvirt' group is just to allow password-less polkit access to
# libvirtd. The uid number is irrelevant, so we use dynamic allocation
# described at the above link.
getent group libvirt >/dev/null || groupadd -r libvirt

exit 0

%post daemon

%systemd_post virtlockd.socket virtlockd-admin.socket
%systemd_post virtlogd.socket virtlogd-admin.socket
%systemd_post libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_post libvirtd-tcp.socket libvirtd-tls.socket
%systemd_post libvirtd.service

# request daemon restart in posttrans
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%preun daemon
%systemd_preun libvirtd.service
%systemd_preun libvirtd-tcp.socket libvirtd-tls.socket
%systemd_preun libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_preun virtlogd.socket virtlogd-admin.socket virtlogd.service
%systemd_preun virtlockd.socket virtlockd-admin.socket virtlockd.service

%postun daemon
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    /bin/systemctl reload-or-try-restart virtlockd.service >/dev/null 2>&1 || :
    /bin/systemctl reload-or-try-restart virtlogd.service >/dev/null 2>&1 || :
fi

# In upgrade scenario we must explicitly enable virtlockd/virtlogd
# sockets, if libvirtd is already enabled and start them if
# libvirtd is running, otherwise you'll get failures to start
# guests
%triggerpostun daemon -- libvirt-daemon < 1.3.0
if [ $1 -ge 1 ] ; then
    /bin/systemctl is-enabled libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl enable virtlogd.socket virtlogd-admin.socket || :
    /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl start virtlogd.socket virtlogd-admin.socket || :
fi

%posttrans daemon
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    # See if user has previously modified their install to
    # tell libvirtd to use --listen
    grep -E '^LIBVIRTD_ARGS=.*--listen' /etc/sysconfig/libvirtd 1>/dev/null 2>&1
    if test $? = 0
    then
        # Then lets keep honouring --listen and *not* use
        # systemd socket activation, because switching things
        # might confuse mgmt tool like puppet/ansible that
        # expect the old style libvirtd
        /bin/systemctl mask libvirtd.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-ro.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-admin.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tls.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tcp.socket >/dev/null 2>&1 || :
    else
        # Old libvirtd owns the sockets and will delete them on
        # shutdown. Can't use a try-restart as libvirtd will simply
        # own the sockets again when it comes back up. Thus we must
        # do this particular ordering, so that we get libvirtd
        # running with socket activation in use
        /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1
        if test $? = 0
        then
            /bin/systemctl stop libvirtd.service >/dev/null 2>&1 || :

            /bin/systemctl try-restart libvirtd.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-ro.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-admin.socket >/dev/null 2>&1 || :

            /bin/systemctl start libvirtd.service >/dev/null 2>&1 || :
        fi
    fi
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%postun daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%post daemon-config-network
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    # see if the network used by default network creates a conflict,
    # and try to resolve it
    # NB: 192.168.122.0/24 is used in the default.xml template file;
    # do not modify any of those values here without also modifying
    # them in the template.
    orig_sub=122
    sub=${orig_sub}
    nl='
'
    routes="${nl}$(ip route show | cut -d' ' -f1)${nl}"
    case ${routes} in
      *"${nl}192.168.${orig_sub}.0/24${nl}"*)
        # there was a match, so we need to look for an unused subnet
        for new_sub in $(seq 124 254); do
          case ${routes} in
          *"${nl}192.168.${new_sub}.0/24${nl}"*)
            ;;
          *)
            sub=$new_sub
            break;
            ;;
          esac
        done
        ;;
      *)
        ;;
    esac

    sed -e "s/${orig_sub}/${sub}/g" \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
    # libvirt saves this file with mode 0600
    chmod 0600 %{_sysconfdir}/libvirt/qemu/networks/default.xml

    # Make sure libvirt picks up the new network defininiton
    mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
    touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-network
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-config-nwfilter
for datadir_file in %{_datadir}/libvirt/nwfilter/*.xml; do
  sysconfdir_file=%{_sysconfdir}/libvirt/nwfilter/$(basename "$datadir_file")
  if [ ! -f "$sysconfdir_file" ]; then
    # libvirt saves these files with mode 600
    install -m 0600 "$datadir_file" "$sysconfdir_file"
  fi
done
# Make sure libvirt picks up the new nwfilter defininitons
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%posttrans daemon-config-nwfilter
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :


%if %{with_qemu}
%pre daemon-driver-qemu
# We want soft static allocation of well-known ids, as disk images
# are commonly shared across NFS mounts by id rather than name; see
# https://fedoraproject.org/wiki/Packaging:UsersAndGroups
getent group kvm >/dev/null || groupadd -f -g 36 -r kvm
getent group qemu >/dev/null || groupadd -f -g 107 -r qemu
if ! getent passwd qemu >/dev/null; then
  if ! getent passwd 107 >/dev/null; then
    useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  else
    useradd -r -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  fi
fi
exit 0
%endif

%preun client

%systemd_preun libvirt-guests.service

%post client
%systemd_post libvirt-guests.service

%postun client
%systemd_postun libvirt-guests.service

%if %{with_lxc}
%pre login-shell
getent group virtlogin >/dev/null || groupadd -r virtlogin
exit 0
%endif

%files

%files docs
%doc AUTHORS.rst NEWS.rst README.rst
%doc libvirt-docs/*

%files daemon

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%{_unitdir}/virtproxyd.service
%{_unitdir}/virtproxyd.socket
%{_unitdir}/virtproxyd-ro.socket
%{_unitdir}/virtproxyd-admin.socket
%{_unitdir}/virtproxyd-tcp.socket
%{_unitdir}/virtproxyd-tls.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/virtproxyd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlogd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtproxyd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_prefix}/lib/sysctl.d/60-libvirtd.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%dir %{_datadir}/libvirt/

%ghost %dir %{_rundir}/libvirt/

%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/


%dir %attr(0755, root, root) %{_libdir}/libvirt/
%dir %attr(0755, root, root) %{_libdir}/libvirt/connection-driver/
%dir %attr(0755, root, root) %{_libdir}/libvirt/lock-driver
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/lockd.so

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/virtproxyd.aug
%{_datadir}/augeas/lenses/tests/test_virtproxyd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%if %{with_qemu}
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%endif

%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper

%attr(0755, root, root) %{_bindir}/virt-ssh-helper

%attr(0755, root, root) %{_sbindir}/libvirtd
%attr(0755, root, root) %{_sbindir}/virtproxyd
%attr(0755, root, root) %{_sbindir}/virtlogd
%attr(0755, root, root) %{_sbindir}/virtlockd

%{_mandir}/man8/libvirtd.8*
%{_mandir}/man8/virtlogd.8*
%{_mandir}/man8/virtlockd.8*
%{_mandir}/man7/virkey*.7*

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml

%files daemon-config-nwfilter
%dir %{_datadir}/libvirt/nwfilter/
%{_datadir}/libvirt/nwfilter/*.xml
%ghost %{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%config(noreplace) %{_sysconfdir}/sysconfig/virtinterfaced
%config(noreplace) %{_sysconfdir}/libvirt/virtinterfaced.conf
%{_datadir}/augeas/lenses/virtinterfaced.aug
%{_datadir}/augeas/lenses/tests/test_virtinterfaced.aug
%{_unitdir}/virtinterfaced.service
%{_unitdir}/virtinterfaced.socket
%{_unitdir}/virtinterfaced-ro.socket
%{_unitdir}/virtinterfaced-admin.socket
%attr(0755, root, root) %{_sbindir}/virtinterfaced
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so

%files daemon-driver-network
%config(noreplace) %{_sysconfdir}/sysconfig/virtnetworkd
%config(noreplace) %{_sysconfdir}/libvirt/virtnetworkd.conf
%{_datadir}/augeas/lenses/virtnetworkd.aug
%{_datadir}/augeas/lenses/tests/test_virtnetworkd.aug
%{_unitdir}/virtnetworkd.service
%{_unitdir}/virtnetworkd.socket
%{_unitdir}/virtnetworkd-ro.socket
%{_unitdir}/virtnetworkd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnetworkd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%ghost %dir %{_rundir}/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libexecdir}/libvirt_leaseshelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so

%if %{with_firewalld_zone}
%{_prefix}/lib/firewalld/zones/libvirt.xml
%endif

%files daemon-driver-nodedev
%config(noreplace) %{_sysconfdir}/sysconfig/virtnodedevd
%config(noreplace) %{_sysconfdir}/libvirt/virtnodedevd.conf
%{_datadir}/augeas/lenses/virtnodedevd.aug
%{_datadir}/augeas/lenses/tests/test_virtnodedevd.aug
%{_unitdir}/virtnodedevd.service
%{_unitdir}/virtnodedevd.socket
%{_unitdir}/virtnodedevd-ro.socket
%{_unitdir}/virtnodedevd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnodedevd
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so

%files daemon-driver-nwfilter
%config(noreplace) %{_sysconfdir}/sysconfig/virtnwfilterd
%config(noreplace) %{_sysconfdir}/libvirt/virtnwfilterd.conf
%{_datadir}/augeas/lenses/virtnwfilterd.aug
%{_datadir}/augeas/lenses/tests/test_virtnwfilterd.aug
%{_unitdir}/virtnwfilterd.service
%{_unitdir}/virtnwfilterd.socket
%{_unitdir}/virtnwfilterd-ro.socket
%{_unitdir}/virtnwfilterd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnwfilterd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%ghost %dir %{_rundir}/libvirt/network/
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so

%files daemon-driver-secret
%config(noreplace) %{_sysconfdir}/sysconfig/virtsecretd
%config(noreplace) %{_sysconfdir}/libvirt/virtsecretd.conf
%{_datadir}/augeas/lenses/virtsecretd.aug
%{_datadir}/augeas/lenses/tests/test_virtsecretd.aug
%{_unitdir}/virtsecretd.service
%{_unitdir}/virtsecretd.socket
%{_unitdir}/virtsecretd-ro.socket
%{_unitdir}/virtsecretd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtsecretd
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so

%files daemon-driver-storage

%files daemon-driver-storage-core
%config(noreplace) %{_sysconfdir}/sysconfig/virtstoraged
%config(noreplace) %{_sysconfdir}/libvirt/virtstoraged.conf
%{_datadir}/augeas/lenses/virtstoraged.aug
%{_datadir}/augeas/lenses/tests/test_virtstoraged.aug
%{_unitdir}/virtstoraged.service
%{_unitdir}/virtstoraged.socket
%{_unitdir}/virtstoraged-ro.socket
%{_unitdir}/virtstoraged-admin.socket
%attr(0755, root, root) %{_sbindir}/virtstoraged
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_fs.so

%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%if %{with_storage_iscsi_direct}
%files daemon-driver-storage-iscsi-direct
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi-direct.so
%endif

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_sheepdog}
%files daemon-driver-storage-sheepdog
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_sheepdog.so
%endif

%if %{with_storage_zfs}
%files daemon-driver-storage-zfs
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_zfs.so
%endif

%if %{with_qemu}
%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/sysconfig/virtqemud
%config(noreplace) %{_sysconfdir}/libvirt/virtqemud.conf
%{_datadir}/augeas/lenses/virtqemud.aug
%{_datadir}/augeas/lenses/tests/test_virtqemud.aug
%{_unitdir}/virtqemud.service
%{_unitdir}/virtqemud.socket
%{_unitdir}/virtqemud-ro.socket
%{_unitdir}/virtqemud-admin.socket
%attr(0755, root, root) %{_sbindir}/virtqemud
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%ghost %dir %{_rundir}/libvirt/qemu/
%dir %attr(0751, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/cache/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/swtpm/
%dir %attr(0730, tss, tss) %{_localstatedir}/log/swtpm/libvirt/qemu/
%{_bindir}/virt-qemu-run
%{_mandir}/man1/virt-qemu-run.1*
%endif

%if %{with_lxc}
%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/sysconfig/virtlxcd
%config(noreplace) %{_sysconfdir}/libvirt/virtlxcd.conf
%{_datadir}/augeas/lenses/virtlxcd.aug
%{_datadir}/augeas/lenses/tests/test_virtlxcd.aug
%{_unitdir}/virtlxcd.service
%{_unitdir}/virtlxcd.socket
%{_unitdir}/virtlxcd-ro.socket
%{_unitdir}/virtlxcd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtlxcd
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%ghost %dir %{_rundir}/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%endif

%if %{with_libxl}
%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/sysconfig/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/virtxend.conf
%{_datadir}/augeas/lenses/virtxend.aug
%{_datadir}/augeas/lenses/tests/test_virtxend.aug
%{_unitdir}/virtxend.service
%{_unitdir}/virtxend.socket
%{_unitdir}/virtxend-ro.socket
%{_unitdir}/virtxend-admin.socket
%attr(0755, root, root) %{_sbindir}/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%ghost %dir %{_rundir}/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%endif

%if %{with_vbox}
%files daemon-driver-vbox
%config(noreplace) %{_sysconfdir}/sysconfig/virtvboxd
%config(noreplace) %{_sysconfdir}/libvirt/virtvboxd.conf
%{_datadir}/augeas/lenses/virtvboxd.aug
%{_datadir}/augeas/lenses/tests/test_virtvboxd.aug
%{_unitdir}/virtvboxd.service
%{_unitdir}/virtvboxd.socket
%{_unitdir}/virtvboxd-ro.socket
%{_unitdir}/virtvboxd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvboxd
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%endif

%if %{with_qemu_tcg}
%files daemon-qemu
%endif

%if %{with_qemu_kvm}
%files daemon-kvm
%endif

%if %{with_lxc}
%files daemon-lxc
%endif

%if %{with_libxl}
%files daemon-xen
%endif

%if %{with_vbox}
%files daemon-vbox
%endif

%if %{with_sanlock}
%files lock-sanlock
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/libvirt/libxl-sanlock.conf
    %endif
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/sanlock.so
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0770, root, sanlock) %{_localstatedir}/lib/libvirt/sanlock
%{_sbindir}/virt-sanlock-cleanup
%{_mandir}/man8/virt-sanlock-cleanup.8*
%attr(0755, root, root) %{_libexecdir}/libvirt_sanlock_helper
%endif

%files client
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate

%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%if %{with_qemu}
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%endif

%{_datadir}/bash-completion/completions/virsh


%{_unitdir}/libvirt-guests.service
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%attr(0755, root, root) %{_libexecdir}/libvirt-guests.sh

%files libs -f %{name}.lang
%license COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config(noreplace) %{_sysconfdir}/libvirt/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%{_datadir}/libvirt/schemas/*.rng

%{_datadir}/libvirt/cpu_map/*.xml

%{_datadir}/libvirt/test-screenshot.png

%files admin
%{_mandir}/man1/virt-admin.1*
%{_bindir}/virt-admin
%{_datadir}/bash-completion/completions/virt-admin

%files bash-completion
%{_datadir}/bash-completion/completions/vsh

%if %{with_wireshark}
%files wireshark
%{wireshark_plugindir}/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%if %{with_lxc}
%files login-shell
%attr(4750, root, virtlogin) %{_bindir}/virt-login-shell
%{_libexecdir}/virt-login-shell-helper
%config(noreplace) %{_sysconfdir}/libvirt/virt-login-shell.conf
%{_mandir}/man1/virt-login-shell.1*
%endif

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/virterror.h
%{_includedir}/libvirt/libvirt.h
%{_includedir}/libvirt/libvirt-admin.h
%{_includedir}/libvirt/libvirt-common.h
%{_includedir}/libvirt/libvirt-domain.h
%{_includedir}/libvirt/libvirt-domain-checkpoint.h
%{_includedir}/libvirt/libvirt-domain-snapshot.h
%{_includedir}/libvirt/libvirt-event.h
%{_includedir}/libvirt/libvirt-host.h
%{_includedir}/libvirt/libvirt-interface.h
%{_includedir}/libvirt/libvirt-network.h
%{_includedir}/libvirt/libvirt-nodedev.h
%{_includedir}/libvirt/libvirt-nwfilter.h
%{_includedir}/libvirt/libvirt-secret.h
%{_includedir}/libvirt/libvirt-storage.h
%{_includedir}/libvirt/libvirt-stream.h
%{_includedir}/libvirt/libvirt-qemu.h
%{_includedir}/libvirt/libvirt-lxc.h
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc

%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml


%changelog
* Mon Jan 10 2022 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-14.6.el8
- qemu_validate: Allow kvm hint-dedicated on non-passthrough VMs (rhbz#2034942)

* Wed Oct 20 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-14.5.el8
- qemu: Check if unpriv_sgio is already set before trying to set it (rhbz#2012223)

* Fri Aug 27 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-14.4.el8
- security: fix SELinux label generation logic (CVE-2021-3631)
- storage_driver: Unlock object on ACL fail in storagePoolLookupByTargetPath (CVE-2021-3667)
- util: directly query KVM for TSC scaling support (rhbz#1996130)

* Tue Jul 20 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-14.3.el8
- qemu: Signal domain condition in qemuProcessStop a bit later (rhbz#1983694)

* Fri Jul 16 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-14.2.el8
- storage: add support for QCOW2 cluster_size option (rhbz#1973269)
- storage_file: add support to probe cluster_size from QCOW2 images (rhbz#1973269)

* Mon May 24 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-14.1.el8
- qemu: blockjob: Transition into 'ready' state only from expected states (rhbz#1955667)

* Thu May  6 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-14
- conf: Fix heap corruption when hot-adding a lease (rhbz#1953577)

* Wed Apr  7 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-13
- Revert "remote: Add libvirtd dependency to virt-guest-shutdown.target" (rhbz#1946697)

* Tue Apr  6 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-12
- util: Document limit-related functions (rhbz#1916346)
- util: Simplify stubs (rhbz#1916346)
- util: Always pass a pid to virProcessSetMax*() (rhbz#1916346)
- util: Introduce virProcess{Get, Set}Limit() (rhbz#1916346)
- qemu: Make some minor tweaks (rhbz#1916346)
- qemu: Set all limits at the same time (rhbz#1916346)
- util: Have virCommand remember whether limits are set (rhbz#1916346)
- qemu: Set limits only when explicitly asked to do so (rhbz#1916346)
- util: Don't special-case setting a limit to zero (rhbz#1916346)
- conf: Rename original_memlock -> originalMemlock (rhbz#1916346)
- tests: Mock virProcessGetMaxMemLock() (rhbz#1916346)
- util: Try to get limits from /proc (rhbz#1916346)
- qemu: Don't ignore virProcessGetMaxMemLock() errors (rhbz#1916346)
- qemu: Refactor qemuDomainAdjustMaxMemLock() (rhbz#1916346)
- qemu: Only raise memlock limit if necessary (rhbz#1916346)

* Fri Mar 26 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-11
- qemu: backup: Restore security label on backup disk store image on VM termination (rhbz#1939082)
- qemuCheckpointDiscardBitmaps: Refuse to delete checkpoint with NULL bitmap name (rhbz#1941600)
- virDomainCheckpointRedefinePrep: Assign default bitmap names when domain XML is missing (rhbz#1941600)

* Fri Mar 19 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-10
- util: Move glib event loop workaround to glibcompat (rhbz#1931331)
- glib: Use safe glib event workaround in other event loops (rhbz#1931331)
- src: ensure GSource background unref happens in correct event loop (rhbz#1931331)
- qemu_driver: fix setting vcpu_quota if not all vCPUs are online (rhbz#1938093)

* Fri Mar 12 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-9
- virSystemdCreateMachine: Use proper format string for uint64_t when constructing gvariant (rhbz#1937287)
- virsystemdtest: Call at least one virSystemdCreateMachine with 'maxthreads' > 0 (rhbz#1937287)
- backup: Store 'apiFlags' in private section of virDomainBackupDef (rhbz#1937598)
- qemuBackupJobTerminate: Fix job termination for inactive VMs (rhbz#1937598)
- virLockSpaceNewPostExecRestart: Fix out-of-bounds array access (rhbz#1912243)
- virnetdaemon: Introduce virNetDaemonQuitExecRestart (rhbz#1912243)
- virtlo(g|ck)d: Fix exec-restart (rhbz#1912243)

* Thu Mar  4 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-8
- cpu_map: Fix spelling of svme-addr-chk feature (rhbz#1920628)
- domain_validate: use defines for cpu period and quota limits (rhbz#1935048)
- docs: use proper cpu quota value in our documentation (rhbz#1935048)
- vircgroup: enforce range limit for cpu.shares (rhbz#1935048)
- cgroup: use virCgroupSetCpuShares instead of virCgroupSetupCpuShares (rhbz#1935048)
- vircgroup: drop unused function virCgroupSetupCpuShares (rhbz#1935048)

* Tue Mar  2 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-7
- qemu: allow migration of generic <hostdev> with <teaming> (rhbz#1927984)
- docs: fix bad cut/paste in <teaming> example (rhbz#1927984)
- qemu_domainjob: Make copy of owner API (rhbz#1932814)
- storageBackendProbeTarget: Check return value of virStorageSourceNewFromBacking (rhbz#1933050)
- qemuBackupJobTerminate: Move cleanup of temp files earlier (rhbz#1933051)
- qemuBackupJobTerminate: Don't calculate backup job stats if VM isn't active (rhbz#1933051)
- cpumap: Add support for ibrs CPU feature (rhbz#1920628)
- cpumap: Add support for svme-addr-check CPU feature (rhbz#1920628)
- cpu_map: Add EPYC-Milan x86 CPU model (rhbz#1920628)
- cpu_map: Install x86_EPYC-Milan.xml (rhbz#1920628)

* Tue Feb 23 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-6
- api: Discourage use of VIR_DOMAIN_SNAPSHOT_CREATE_QUIESCE (rhbz#1928819)
- qemuSnapshotCreateActiveExternal: Don't thaw filesystems when freeze fails (rhbz#1928819)
- qemuSnapshotFSFreeze: Don't return -2 (rhbz#1928819)
- qemu: capabilities: Introduce QEMU_CAPS_MIGRATION_PARAM_BLOCK_BITMAP_MAPPING (rhbz#1867085)
- qemu: Probe whether an image is 'qcow2 v2' from query-named-block-nodes (rhbz#1867085)
- qemu: migration: Create qcow2 v3 images for VIR_MIGRATE_NON_SHARED_DISK (rhbz#1867085)
- qemu: monitor: Introduce qemuMonitorBitmapRemove (rhbz#1867085)
- qemu: blockjob: Use qemuMonitorBitmapRemove for single bitmap removal (rhbz#1867085)
- qemu: migration_params: Add infrastructure for 'dirty-bitmaps' migration feature (rhbz#1867085)
- qemu: migration_cookie: Add XML handling for setting up bitmap migration (rhbz#1867085)
- qemu: migration_cookie: Add helpers for transforming the cookie into migration params (rhbz#1867085)
- qemu: domain: Store list of temporary bitmaps for migration in status XML (rhbz#1867085)
- qemu: migration: Clean up temporary bitmaps when cancelling a migration (rhbz#1867085)
- qemu: migration: Migrate block dirty bitmaps corresponding to checkpoints (rhbz#1867085)
- qemu: capabilities: Enable QEMU_CAPS_INCREMENTAL_BACKUP (rhbz#1799015)

* Mon Feb 22 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-5
- virsystemd: export virSystemdHasMachined (rhbz#1798464)
- virsystemd: introduce virSystemdGetMachineByPID (rhbz#1798464)
- virsystemd: introduce virSystemdGetMachineUnitByPID (rhbz#1798464)
- vircgroup: use DBus call to systemd for some APIs (rhbz#1798464)
- vircgroupv1: refactor virCgroupV1DetectPlacement (rhbz#1798464)
- vircgroupv2: move task into cgroup before enabling controllers (rhbz#1798464)
- vircgroup: introduce virCgroupV1Exists and virCgroupV2Exists (rhbz#1798464)
- vircgroup: introduce nested cgroup to properly work with systemd (rhbz#1798464)
- tests: add cgroup nested tests (rhbz#1798464)
- vircgroup: correctly free nested virCgroupPtr (rhbz#1798464)
- src: add missing virstoragefile.h includes (rhbz#1884659)
- virstoragefile: properly include virstoragefile.h header (rhbz#1884659)
- virstoragefile: change virStorageSource->drv to void pointer (rhbz#1884659)
- storage: move storage file sources to separate directory (rhbz#1884659)
- util: move virStorageSourceFindByNodeName into qemu_domain (rhbz#1884659)
- util: extract storage file probe code into virtstoragefileprobe.c (rhbz#1884659)
- util: extract virStorageFile code into storage_source (rhbz#1884659)
- util: move virStorageFileBackend code into storage_file (rhbz#1884659)
- util: move virStorageFileProbe code into storage_file (rhbz#1884659)
- util: move virStorageSource code into conf (rhbz#1884659)
- util: move virStorageEncryption code into conf (rhbz#1884659)
- storage_source: use virStorageSource prefix for all functions (rhbz#1884659)
- conf: rename virDomainCheckVirtioOptions (rhbz#1884659)
- qemu_alias: introduce qemuDomainGetVhostUserAlias helper (rhbz#1884659)
- qemu_validate: move and refactor qemuValidateDomainDefVirtioFSSharedMemory (rhbz#1884659)
- docs: introduces new vhostuser disk type (rhbz#1884659)
- conf: implement support for vhostuser disk (rhbz#1884659)
- qemu_capabilities: introduce vhost-user-blk capability (rhbz#1884659)
- qemu: implement vhost-user-blk support (rhbz#1884659)
- conf: allow virtio driver attributes for vhostuser disk (rhbz#1884659)
- virStorageSourceClear: Unref @vhostuser (rhbz#1884659)
- qemu: Fix libvirt hang due to early TPM device stop (rhbz#1914643)

* Fri Feb 19 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-4
- qemu_capabilities: Introduce QEMU_CAPS_X_USE_CANONICAL_PATH_FOR_RAMBLOCK_ID (rhbz#1912201)
- qemu: Do not Use canonical path for system memory (rhbz#1912201)
- qemu: match alias when looking for proper <interface> to detach. (rhbz#1926190)
- conf: make teaming info an official type (rhbz#1927984)
- conf: use virDomainNetTeamingInfoPtr instead of virDomainNetTeamingInfo (rhbz#1927984)
- conf: separate Parse/Format functions for virDomainNetTeamingInfo (rhbz#1927984)
- schema: separate teaming element definition from interface element (rhbz#1927984)
- conf: parse/format <teaming> element in plain <hostdev> (rhbz#1927984)
- qemu: plug <teaming> config from <hostdev> into qemu commandline (rhbz#1927984)
- qemu_hotplug: Don't dereference NULL pointer @newb in qemuDomainChangeNet() (rhbz#1919619)
- qemu: Drop needless check in virDomainFSInfoFormat() (rhbz#1919783)
- qemu: Move qemuAgentFSInfo array free into qemuDomainGetFSInfo() (rhbz#1919783)
- qemu: Bring if() outside from loop in virDomainFSInfoFormat() (rhbz#1919783)
- qemu: Don't lie about @ndevAlias when translating FSInfo (rhbz#1919783)
- conf: Move virDomainCheckVirtioOptions() into domain_validate.c (rhbz#1928840)
- conf: Improve virDomainVirtioOptionsCheckABIStability() (rhbz#1928840)
- qemu: Add virtio related options to vsock (rhbz#1928840)

* Fri Jan 29 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-3
- util: add virNetDevGetPhysPortName (rhbz#1908649)
- util: Add phys_port_name support on virPCIGetNetName (rhbz#1908649)
- cpu_map: Remove intel-pt from x86 CPU models (rhbz#1853972)
- qemu: Avoid crash in qemuStateShutdownPrepare() and qemuStateShutdownWait() (rhbz#1895359)
- qemu: fix release of virDomainObjPtr in SSH key APIs (rhbz#1919856)

* Tue Jan 19 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-2
- meson: Fix build with -Dtest_coverage=true (rhbz#1875380)
- qemu: don't set interface MTU when managed='no' (rhbz#1905929)
- network: explicitly set the MTU of the bridge device. (rhbz#1913561)

* Fri Jan 15 2021 Jiri Denemark <jdenemar@redhat.com> - 7.0.0-1
- Rebased to libvirt-7.0.0 (rhbz#1875380)
- The rebase also fixes the following bugs:
    rhbz#1329644, rhbz#1538879, rhbz#1689168, rhbz#1750315, rhbz#1751664
    rhbz#1767013, rhbz#1810356, rhbz#1819058, rhbz#1839034, rhbz#1858771
    rhbz#1865933, rhbz#1875380, rhbz#1877218, rhbz#1880289, rhbz#1886739
    rhbz#1889131, rhbz#1894053, rhbz#1895359, rhbz#1899527, rhbz#1903953
    rhbz#1904486, rhbz#1904487, rhbz#1904674, rhbz#1905572, rhbz#1908053
    rhbz#1908631, rhbz#1908647, rhbz#1911786, rhbz#1913138, rhbz#1913156
    rhbz#1913315, rhbz#1914842, rhbz#1914954, rhbz#1916097

* Tue Dec  1 2020 Jiri Denemark <jdenemar@redhat.com> - 6.10.0-1
- Rebased to libvirt-6.10.0 (rhbz#1875380)
- The rebase also fixes the following bugs:
    rhbz#1329644, rhbz#1354391, rhbz#1487068, rhbz#1509908, rhbz#1555398
    rhbz#1658082, rhbz#1767013, rhbz#1771450, rhbz#1789243, rhbz#1790837
    rhbz#1795137, rhbz#1839095, rhbz#1850614, rhbz#1857208, rhbz#1861280
    rhbz#1870072, rhbz#1872254, rhbz#1873441, rhbz#1878450, rhbz#1879477
    rhbz#1879792, rhbz#1883328, rhbz#1883588, rhbz#1888537, rhbz#1892130
    rhbz#1895204, rhbz#1897105

* Wed Nov  4 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-8
- vircommand.c: write child pidfile before process tuning in virExec() (rhbz#1882093)
- util: Avoid double free in virProcessSetAffinity (rhbz#1819801)
- util: keep track of full GSource object not source ID number (rhbz#1894045)
- util: avoid crash due to race in glib event loop code (rhbz#1894045)
- qemu: Use g_autofree in qemuMigrationSrcConnect (rhbz#1638889)
- qemu: Rework qemuMigrationSrcConnect (rhbz#1638889)
- virsh: Reuse existing variable when parsing migrate --disks-port (rhbz#1638889)
- qemu: Rework starting NBD server for migration (rhbz#1638889)
- tests: Add simple test for virDomainMigrateCheckNotLocal (rhbz#1638889)
- qemu: Allow NBD migration over UNIX socket (rhbz#1638889)
- peer2peer migration: allow connecting to local sockets (rhbz#1638889)
- qemu: Allow migration over UNIX socket (rhbz#1638889)
- docs: migration: Fix syntax (rhbz#1638889)
- qemu: Don't try to start NBD server twice (rhbz#1638889)

* Mon Oct 12 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-7
- rpc: gendispatch: handle empty flags (CVE-2020-25637)
- rpc: add support for filtering @acls by uint params (CVE-2020-25637)
- rpc: require write acl for guest agent in virDomainInterfaceAddresses (CVE-2020-25637)
- qemu: agent: set ifname to NULL after freeing (CVE-2020-25637)
- Add testdata for AMD EPYC 7502 (rhbz#1861703)
- cpu_map: Defined and enable EPYC-Rome model (rhbz#1861703)
- cputest: Update QEMU data for Ryzen 9 3900X (rhbz#1861703)
- cpu_map: Remove monitor feature from EPYC-Rome (rhbz#1861703)

* Wed Sep 16 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-6
- virDomainHostdevSubsysSCSIiSCSIClear: Inline contents into only caller (rhbz#1876467)
- virDomainStorageNetworkParseHosts: Switch to a more modern XML parsing approach (rhbz#1876467)
- virDomainHostdevSubsysSCSIHostDefParseXML: Switch to a more modern XML parsing approach (rhbz#1876467)
- qemuxml2argvtest: hostdev-scsi-virtio-scsi: Add hostdev with useralias (rhbz#1876467)
- conf: Add virStorageSource member for SCSI host device config data (rhbz#1876467)
- tests: qemustatusxml2xmldata: Rename 'disk-secinfo-upgrade' case to 'upgrade' (rhbz#1876467)
- tests: qemustatusxml2xmldata: Add local SCSI hostdev to 'upgrade' case (rhbz#1876467)
- qemu: domain: Fill in (i)SCSI backend nodename if it is not present in status XML (rhbz#1876467)
- qemuBuildHostdevSCSI(A|De)tachPrepare: Use virStorageSource in def for SCSI hostdevs (rhbz#1876467)
- qemuBlockStorageSourceAttachData: remove 'storageNodeNameCopy' (rhbz#1876467)
- qemu: domain: Extract preparation of hostdev specific data to a separate function (rhbz#1876467)
- qemuDomainSecretHostdevPrepare: remove (rhbz#1876467)
- qemuDomainPrepareHostdev: Allocate backend nodenames in the prepare function (rhbz#1876467)
- qemuDomainPrepareHostdev: base hostdev secret object names on backend alias (rhbz#1876467)
- qemuDomainPrepareHostdev: Don't base backend nodename on device alias (rhbz#1876467)
- qemuxml2argvtest: hostdev-scsi-virtio-scsi: Use longer user-alias for SCSI hostdev (rhbz#1876467)
- qemustatusxml2xml: backup-pull: Test private data formatting/parsing (rhbz#1870488)
- qemu: backup: Remove note that TLS should be implemented (rhbz#1870488)
- qemu: backup: Write TLS cert and secret object aliases into status XML (rhbz#1870488)
- qemuxml2argvtest: hostdev-scsi-virtio-scsi: Add <readonly/> to one of the iSCSI hostdevs (rhbz#1868856)
- qemuBuildHostdevSCSIAttachPrepare: Propagate 'readonly' flag also for iSCSI (rhbz#1868856)

* Mon Sep 14 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-5
- qemu: Do not error out when setting affinity failed (rhbz#1819801)
- qemu: Fix comment in qemuProcessSetupPid (rhbz#1819801)
- Do not report error when setting affinity is allowed to fail (rhbz#1819801)
- qemu: Allow setting affinity to fail and don't report error (rhbz#1819801)
- qemu: snapshot: Collect 'query-named-block-nodes' prior to memory migration (rhbz#1862472)
- check for NULL before calling g_regex_unref (rhbz#1876907)
- virsh: cmdScreenshot: fix cbdata passing to virshStreamSink (rhbz#1875195)
- qemu: Do not silently allow non-available timers on non-x86 systems (rhbz#1754887)
- qemuFirmwareFillDomain: Fill NVRAM template on migration too (rhbz#1852910)
- virnuma: Report error when NUMA -> CPUs translation fails (rhbz#1724866)
- virnuma: Use numa_nodes_ptr when checking available NUMA nodes (rhbz#1876956)
- conf: properly clear out autogenerated macvtap names when formatting/parsing (rhbz#1872611)
- util: replace macvtap name reservation bitmap with a simple counter (rhbz#1837395)
- util: assign tap device names using a monotonically increasing integer (rhbz#1837395)
- util: virNetDevTapCreate: initialize fd to -1 (rhbz#1837395)

* Mon Aug 31 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-4
- vircgroupv2devices: fix counting entries in BPF map (rhbz#1833321)
- qemu: fix crash in qemuDomainSetBlkioParameters without cgroups (rhbz#1808293)
- RNG: Allow interleaving of /domain/cpu/numa/cell children (rhbz#1786303)

* Mon Aug 31 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-3
- virdevmapper: Don't cache device-mapper major (rhbz#1867527)
- virdevmapper: Handle kernel without device-mapper support (rhbz#1867527)
- virdevmapper: Ignore all errors when opening /dev/mapper/control (rhbz#1867527)
- numa_conf: Properly check for caches in virDomainNumaDefValidate() (rhbz#1786303)
- virfdstream: Use g_autofree in virFDStreamThreadDoRead() (rhbz#1852528)
- virFDStreamMsgQueuePush: Clear pointer to passed message (rhbz#1852528)
- virfdstream: Use autoptr for virFDStreamMsg (rhbz#1852528)
- virfdstream: Use g_new0() instead of VIR_ALLOC() (rhbz#1852528)
- virfdstream: Use VIR_AUTOCLOSE() (rhbz#1852528)
- virfdstream: Drop some needless labels (rhbz#1852528)
- libvirt-storage: Document volume upload/download stream format (rhbz#1852528)
- virsh: Pass virshStreamCallbackDataPtr to virshStreamSink() and virshStreamSkip() (rhbz#1852528)
- virsh: Track if vol-upload or vol-download work over a block device (rhbz#1852528)
- virshStreamSkip: Emulate skip for block devices (rhbz#1852528)
- virfdstream: Allow sparse stream vol-download (rhbz#1852528)
- virshStreamInData: Handle block devices (rhbz#1852528)
- virfdstream: Emulate skip for block devices (rhbz#1852528)
- virnuma: Don't work around numa_node_to_cpus() for non-existent nodes (rhbz#1860231)

* Wed Aug  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-2
- util: Fix logic in virFileSetCOW (rhbz#1866157)

* Tue Aug  4 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-1
- Rebased to libvirt-6.6.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1854372, rhbz#1602328, rhbz#1745059, rhbz#1786303, rhbz#1799010
    rhbz#1814573, rhbz#1821694, rhbz#1822631, rhbz#1829829, rhbz#1840053
    rhbz#1851016, rhbz#1852311, rhbz#1852741, rhbz#1854684, rhbz#1857204
    rhbz#1857735, rhbz#1857967, rhbz#1858260, rhbz#1860875

* Thu Jul  9 2020 Jiri Denemark <jdenemar@redhat.com> - 6.5.0-1
- Rebased to libvirt-6.5.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1432902, rhbz#1634829, rhbz#1640869, rhbz#1739221, rhbz#1823639
    rhbz#1826543, rhbz#1829543, rhbz#1829544, rhbz#1829545, rhbz#1837990
    rhbz#1838975, rhbz#1840307, rhbz#1845012, rhbz#1847234, rhbz#1847259
    rhbz#1847791, rhbz#1849516

* Tue Jun  2 2020 Jiri Denemark <jdenemar@redhat.com> - 6.4.0-1
- Rebased to libvirt-6.4.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1235511, rhbz#1769598, rhbz#1839926, rhbz#1778819, rhbz#1783355
    rhbz#1813306, rhbz#1820040, rhbz#1822878, rhbz#1825785, rhbz#1829550
    rhbz#1832710

* Tue May  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.3.0-1
- Rebased to libvirt-6.3.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1823309, rhbz#1229255, rhbz#1499880, rhbz#1557902, rhbz#1761678
    rhbz#1772838, rhbz#1791522, rhbz#1793705, rhbz#1811906, rhbz#1812100
    rhbz#1812827, rhbz#1813310, rhbz#1820376, rhbz#1821988, rhbz#1822538
    rhbz#1824368, rhbz#1826652, rhbz#1826746

* Fri Apr  3 2020 Jiri Denemark <jdenemar@redhat.com> - 6.2.0-1
- Rebased to libvirt-6.2.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1460920, rhbz#1591411, rhbz#1727263, rhbz#1750219, rhbz#1781913
    rhbz#1785091, rhbz#1791236, rhbz#1813852, rhbz#1817831, rhbz#1466177
    rhbz#1515677, rhbz#1592273, rhbz#1611061, rhbz#1639596, rhbz#1724928
    rhbz#1784040, rhbz#1793036, rhbz#1810857, rhbz#1812531, rhbz#1813306
    rhbz#1814481, rhbz#1814486, rhbz#1814975, rhbz#1816037, rhbz#1817381
    rhbz#1817955, rhbz#1818030

* Fri Mar 20 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-14
- qemu: Don't crash when getting targets for a multipath (rhbz#1814947)
- virSecretLookupDefCopy: Remove return value (rhbz#1814923)
- virStorageEncryptionSecretCopy: Properly copy internals (rhbz#1814923)
- vmx: shortcut earlier few 'ignore' cases in virVMXParseDisk() (rhbz#1808610)
- vmx: make 'fileName' optional for CD-ROMs (rhbz#1808610)

* Wed Mar 18 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-13
- qemu: Create multipath targets for PRs (rhbz#1814157)

* Tue Mar 17 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-12
- qemuBlockBitmapsHandleCommitStart: Fix allocation of string list (rhbz#1799013)
- qemuBlockBitmapsHandleCommitFinish: Use proper variable to iterate (rhbz#1799013)
- qemublocktest: Add tests for re-enabling of bitmaps after commit (rhbz#1799013)

* Tue Mar 17 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-11
- virbuftest: remove extra G_GNUC_UNUSED markers (rhbz#1808499)
- virbuftest: use g_autofree (rhbz#1808499)
- virbuftest: remove unnecessary labels (rhbz#1808499)
- virbuftest: declare testBufAddStrData earlier (rhbz#1808499)
- virbuftest: use field names when initalizing test info (rhbz#1808499)
- util: add virBufferTrimChars (rhbz#1808499)
- conf: do not generate machine names ending with a dash (rhbz#1808499)
- conf: Don't generate machine names with a dot (rhbz#1808499)
- qemuAgentFSInfoFormatParams: Remove pointless returned value (rhbz#1812965)
- qemuDomainGetGuestInfo: Don't try to free a negative number of entries (rhbz#1812965)
- qemuDomainBlockPivot: Move check prior to executing the pivot steps (rhbz#1803092)
- qemuDomainBlockCopyCommon: Record updated flags to block job (rhbz#1803092)
- qemu: capabilities: Introduce QEMU_CAPS_BLOCKDEV_SNAPSHOT_ALLOW_WRITE_ONLY (rhbz#1803092)
- qemu: blockcopy: Allow late opening of the backing chain of a shallow copy (rhbz#1803092)
- qemuBlockStorageSourceDetachPrepare: Get rid of cleanup section (rhbz#1804750)
- qemu: Don't take double pointer in qemuDomainSecretInfoFree (rhbz#1804750)
- qemuMigrationParamsResetTLS: Adapt to modern memory management (rhbz#1804750)
- qemuMigrationParamsResetTLS: Fix comment (rhbz#1804750)
- qemuDomainSecretInfo: Register autoptr cleanup function (rhbz#1804750)
- qemuDomainSecretAESSetup: Automatically free non-secret locals (rhbz#1804750)
- qemuDomainSecretAESSetup: Allocate and return 'secinfo' here (rhbz#1804750)
- qemuDomainSecretAESSetup: Split out lookup of secret data (rhbz#1804750)
- Remove qemuDomainSecretInfoNew (rhbz#1804750)
- qemu: Introduce another helper for creating alias for a 'secret' object (rhbz#1804750)
- qemuDomainSecretStorageSourcePrepare: Fix naming of alias variables (rhbz#1804750)
- qemuDomainDeviceDiskDefPostParseRestoreSecAlias: Hardcode restored aliases (rhbz#1804750)
- qemu: Split out initialization of secrets for 'iscsi' hostdevs (rhbz#1804750)
- qemuDomainSecretAESSetupFromSecret: Use 'qemuAliasForSecret' (rhbz#1804750)
- qemuDomainSecretStorageSourcePrepare: Change aliases for disk secrets (rhbz#1804750)
- qemuDomainGetSecretAESAlias: Replace outstanding uses with qemuAliasForSecret (rhbz#1804750)
- conf: Add support for modifying ssl validation for https/ftps disks (rhbz#1804750)
- conf: Add support for cookies for HTTP based disks (rhbz#1804750)
- conf: Add support for setting timeout and readahead size for network disks (rhbz#1804750)
- qemuDomainValidateStorageSource: Validate new network storage parameters (rhbz#1804750)
- qemuxml2argvtest: Add test case for disks with http(s) source (rhbz#1804750)
- qemu: block: Implement ssl verification configuration (rhbz#1804750)
- qemu: domain: Store data for 'secret' object representing http cookies (rhbz#1804750)
- qemuDomainSecretStorageSourcePrepare: Setup secret for http cookies (rhbz#1804750)
- qemu: Handle hotplug and commandline for secret objects for http cookies (rhbz#1804750)
- qemu: block: Add support for HTTP cookies (rhbz#1804750)
- qemu: block: Implement readahead and timeout properties for 'curl' driver (rhbz#1804750)
- virstoragefile: Add JSON parser for 'sslverify', 'readahead', 'cookies' and 'timeout' (rhbz#1804750)
- virStorageSourceParseBackingJSONUri: Handle undocumented value 'off' for sslverify (rhbz#1804750)
- qemublocktest: Load QMP schema earlier (rhbz#1804750)
- qemublocktest: Extract schema root for blockdev-add validation (rhbz#1804750)
- qemublocktest: XMLjsonXML: Test formatting/parsing of modern JSON (rhbz#1804750)
- qemublocktest: Add JSON->JSON test cases for block device backends (rhbz#1804750)
- qemu: Pass through arguments of 'ssh' block driver used by libguestfs (rhbz#1804750)
- qemu: capabilities: Add QEMU_CAPS_BLOCKDEV_REOPEN (rhbz#1799013)
- qemu: monitor: Add handler for blockdev-reopen (rhbz#1799013)
- qemu: block: implement helpers for blockdev-reopen (rhbz#1799013)
- qemuCheckpointDiscardBitmaps: Reopen images for bitmap modifications (rhbz#1799013)
- qemuCheckpointDiscardBitmaps: Use correct field for checkpoint bitmap name (rhbz#1799013)
- qemuDomainBlockCommit: Move checks depending on capabilities after liveness check (rhbz#1799013)
- qemu: domain: Extract formatting of 'commit' blockjob data into a function (rhbz#1799013)
- qemu: domain: Extract parsing of 'commit' blockjob data into a function (rhbz#1799013)
- qemu: blockjob: Store list of bitmaps disabled prior to commit (rhbz#1799013)
- qemublocktest: Fix and optimize fake image chain (rhbz#1799013)
- qemu: block: Implement helpers for dealing with bitmaps during block commit (rhbz#1799013)
- qemublocktest: Add tests for handling of bitmaps during block-commit (rhbz#1799013)
- qemublocktest: Add more tests for block-commit bitmap handling with snapshots (rhbz#1799013)
- qemublocktest: Add tests of broken bitmap chain handling during block-commit (rhbz#1799013)
- qemuBlockJobDiskNewCommit: Propagate 'disabledBitmapsBase' (rhbz#1799013)
- qemuDomainBlockCommit: Handle bitmaps on start of commit (rhbz#1799013)
- qemuDomainBlockPivot: Handle merging of bitmaps when pivoting an active block-commit (rhbz#1799013)
- qemu: blockjob: Handle bitmaps after finish of normal block-commit (rhbz#1799013)
- qemu: blockjob: Re-enable bitmaps after failed block-commit (rhbz#1799013)
- qemuDomainGetGuestInfo: don't assign NULL hostname (rhbz#1812965)
- rhel: Enable usage of x-blockdev-reopen (rhbz#1799013)

* Tue Mar 10 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-10
- security: Introduce VIR_SECURITY_DOMAIN_IMAGE_PARENT_CHAIN_TOP flag (rhbz#1803551)
- qemu: Tell secdrivers which images are top parent (rhbz#1803551)
- virDomainDiskTranslateSourcePool: Check for disk type correctly (rhbz#1811728)

* Fri Mar  6 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-9
- conf: use virXMLFormatElement in virDomainFSDefFormat (rhbz#1694166)
- qemu: use def instead of vm->def in qemuExtDevicesStart (rhbz#1694166)
- qemu: eliminate ret in qemuExtDevicesStart (rhbz#1694166)
- docs: render class="literal" with monospace font (rhbz#1694166)
- docs: reduce excessive spacing in ToC for RST files (rhbz#1694166)
- virDomainFSDefFree: Unref private data (rhbz#1694166)
- schema: wrap fsDriver in a choice group (rhbz#1694166)
- qemuExtDevicesStart: pass logManager (rhbz#1694166)
- qemu: pass virDomainObjPtr to qemuExtDevicesSetupCgroup (rhbz#1694166)
- qemuxml2xmltest: set driver as privileged (rhbz#1694166)
- qemu: add QEMU_CAPS_DEVICE_VHOST_USER_FS (rhbz#1694166)
- docs: add virtiofs kbase (rhbz#1694166)
- conf: qemu: add virtiofs fsdriver type (rhbz#1694166)
- conf: add virtiofs-related elements and attributes (rhbz#1694166)
- qemu: add virtiofsd_debug to qemu.conf (rhbz#1694166)
- qemu: validate virtiofs filesystems (rhbz#1694166)
- qemu: forbid migration with vhost-user-fs device (rhbz#1694166)
- qemu: add code for handling virtiofsd (rhbz#1694166)
- qemu: put virtiofsd in the emulator cgroup (rhbz#1694166)
- qemu: use the vhost-user schemas to find binary (rhbz#1694166)
- qemu: build vhost-user-fs device command line (rhbz#1694166)
- RHEL: virscsi: Check device type before getting it's /dev node name (rhbz#1808390)
- RHEL: virscsi: Support TAPEs in virSCSIDeviceGetDevName() (rhbz#1808390)
- RHEL: virscsi: Introduce and use virSCSIDeviceGetUnprivSGIOSysfsPath() (rhbz#1808390)
- RHEL: virutil: Accept non-block devices in virGetDeviceID() (rhbz#1808390)
- RHEL: qemuSetUnprivSGIO: Actually use calculated @sysfs_path to set unpriv_sgio (rhbz#1808390)
- RHEL: qemuCheckUnprivSGIO: use @sysfs_path to get unpriv_sgio (rhbz#1808400)

* Thu Mar  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-8
- util: storagefile: Drop image format probing by file suffix (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Remove impossible error report (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Shuffle around assignment of backing chain depth (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Expect NULL src->path (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Use virHashHasEntry instead of fake pointers (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Extract storage access (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Remove 'cleanup' label (rhbz#1798148)
- tests: virstorage: Fix backing file format of created image (rhbz#1798148)
- virStorageSourceUpdateCapacity: Drop 'probe' argument (rhbz#1798148)
- util: storage: Store backing store format in virStorageSource (rhbz#1798148)
- virStorageSourceNewFromBacking: Also transfer the format (rhbz#1798148)
- virStorageBackendGlusterRefreshVol: Refactor handling of backing store (rhbz#1798148)
- virStorageFileGetMetadataFromBuf: Remove 'backingFormat' argument (rhbz#1798148)
- virStorageFileGetMetadataFromFD: Remove unused 'backingFormat' argument (rhbz#1798148)
- qemu: domain: Convert detected 'iso' image format into 'raw' (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Allow format probing under special circumstances (rhbz#1798148)
- kbase: backing_chains: Clarify some aspects of image probing (rhbz#1798148)
- kbase: backing_chains: Add steps how to securely probe image format (rhbz#1798148)

* Tue Feb 25 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-7
- docs: fix a typo (rhbz#1805742)
- virDomainNetDefClear: Free @persistent name (rhbz#1805742)
- virSecurityManagerMetadataLock: Store locked paths (rhbz#1804672)
- security: Don't remember seclabel for paths we haven't locked successfully (rhbz#1804672)
- security: Don't fail if locking a file on NFS mount fails (rhbz#1804672)

* Fri Feb 21 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-6
- qemuBlockStorageSourceGetBackendProps: Report errors on all switch cases (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Sanitize handling of string list (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: use g_new0 instead of VIR_ALLOC_N (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Remove 'cleanup' label (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Remove ternary operator (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Take virStorageSourcePtr instead of virDomainDiskDefPtr (rhbz#1804603)
- virDomainDiskTranslateSourcePoolAuth: Take virStorageSourcePtr instead of virDomainDiskDefPtr (rhbz#1804603)
- virDomainDiskTranslateISCSIDirect: Take virStorageSourcePtr instead of virDomainDiskDefPtr (rhbz#1804603)
- virDomainDiskTranslateSourcePool: split code to setup one storage source (rhbz#1804603)
- virDomainDiskTranslateSourcePool: Translate 'volume' disks in whole backing chain (rhbz#1804603)
- qemuMonitorJSONBlockdevAdd: Refactor cleanup (rhbz#1798366)
- qemuMonitorJSONBlockdevDel: Refactor cleanup (rhbz#1798366)
- qemuMonitorBlockdevAdd: Take double pointer argument (rhbz#1798366)
- qemu: hotplug: Fix handling of the 'copy-on-read' layer with blockdev (rhbz#1798366)
- virStorageSourceParseBackingJSON: Pass around original backing file string (rhbz#1791788)
- virStorageSourceParseBackingJSON: Move deflattening of json: URIs out of recursion (rhbz#1791788)
- virStorageSourceJSONDriverParser: annotate 'format' drivers (rhbz#1791788)
- virStorageSourceParseBackingJSON: Allow 'json:' pseudo URIs without 'file' wrapper (rhbz#1791788)
- virStorageSourceParseBackingJSON: Prevent arbitrary nesting with format drivers (rhbz#1791788)
- tests: virstorage: Add test cases for "json:" pseudo-URI without 'file' wrapper (rhbz#1791788)
- qemu: domain: Refactor formatting of node names into status XML (rhbz#1791788)
- docs: formatdomain: Close <source> on one of disk examples (rhbz#1791788)
- tests: virstorage: Add test data for json specified raw image with offset/size (rhbz#1791788)
- util: virstoragefile: Add data structure for storing storage source slices (rhbz#1791788)
- qemuBlockStorageSourceGetFormatRawProps: format 'offset' and 'size' for slice (rhbz#1791788)
- qemuDomainValidateStorageSource: Reject unsupported slices (rhbz#1791788)
- qemu: block: forbid creation of storage sources with <slice> (rhbz#1791788)
- docs: Document the new <slices> sub-element of disk's <source> (rhbz#1791788)
- conf: Implement support for <slices> of disk source (rhbz#1791788)
- qemu: domain: Store nodenames of slice in status XML (rhbz#1791788)
- qemu: block: Properly format storage slice into backing store strings (rhbz#1791788)
- tests: qemublock: Add cases for creating image overlays on top of disks with <slice> (rhbz#1791788)
- qemu: Add support for slices of type 'storage' (rhbz#1791788)
- tests: qemu: Add test data for the new <slice> element (rhbz#1791788)
- virStorageSourceParseBackingJSONRaw: Parse 'offset' and 'size' attributes (rhbz#1791788)
- qemuDomainGetStatsIOThread: Don't leak array with 0 iothreads (rhbz#1804548)
- qemuxml2xmltest: Add case for host-model vendor_id (rhbz#1804549)
- cpu_conf: Format vendor_id for host-model CPUs (rhbz#1804549)
- qemu: rename qemuAgentGetFSInfoInternalDisk() (rhbz#1759566)
- qemu: store complete agent filesystem information (rhbz#1759566)
- qemu: Don't store disk alias in qemuAgentDiskInfo (rhbz#1759566)
- qemu: don't access vmdef within qemu_agent.c (rhbz#1759566)
- qemu: remove qemuDomainObjBegin/EndJobWithAgent() (rhbz#1759566)

* Mon Feb 17 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-5
- qemu: do not revert to NULL bandwidth (rhbz#1800505)
- qemu: preserve error on bandwidth rollback (rhbz#1800505)
- tests: Add capabilities for QEMU 5.0.0 on aarch64 (rhbz#1762634)
- qemu: Use switch statement in qemuBuildCpuCommandLine() (rhbz#1762634)
- qemu: Add the QEMU_CAPS_CPU_KVM_NO_ADJVTIME capability (rhbz#1762634)
- conf: Introduce VIR_DOMAIN_TIMER_NAME_ARMVTIMER (rhbz#1762634)
- qemu: Validate configuration for the armvtimer timer (rhbz#1762634)
- qemu: Format the armvtimer timer on the command line (rhbz#1762634)
- tests: Add test case for the armvtimer timer (rhbz#1762634)
- docs: List the armvtimer timer among all others (rhbz#1762634)
- qemu_domain: Modify access to a NVMe disk iff needed (rhbz#1519005)

* Wed Feb  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-4
- qemu: blockcopy: Actually unplug unused images when mirror job fails to start (rhbz#1792195)
- qemu: domain: Extract code to determine topmost nodename to qemuDomainDiskGetTopNodename (rhbz#1792195)
- qemu: Fix value of 'device' argument for blockdev-mirror (rhbz#1792195)
- qemu: Fix value of 'device' argument for block-commit (rhbz#1792195)
- conf: backup: Allow configuration of names exported via NBD (rhbz#1207659)
- qemu: backup: Implement support for backup disk export name configuration (rhbz#1207659)
- qemu: backup: Implement support for backup disk bitmap name configuration (rhbz#1207659)
- util: hash: Improve debugability of "Duplicate key" error message (rhbz#1207659)
- tests: hash: Test case for adding duplicate hash entry (rhbz#1207659)
- qemu: block: Don't skip creation of 'luks' formatted images (rhbz#1371022)
- qemu: monitor: Improve error message when QEMU reply is too large (rhbz#1524278)
- qemu: snapshot: Always rewrite backingStore data when reusing existing images (rhbz#1524278)
- qemu: snapshot: Prevent too-nested domain XML when doing inactive snapshot (rhbz#1524278)
- qemu: checkpoint: Store whether deleted checkpoint is current in a variable (rhbz#1207659)
- qemu: checkpoint: split out checkpoint deletion bitmaps (rhbz#1207659)
- qemu: checkpoint: rename disk->chkdisk in qemuCheckpointDiscardBitmaps (rhbz#1207659)
- qemu: checkpoint: rename disk->chkdisk in qemuCheckpointAddActions (rhbz#1207659)
- qemu: checkpoint: Use disk definition directly when creating checkpoint (rhbz#1207659)
- qemu: checkpoint: tolerate missing disks on checkpoint deletion (rhbz#1207659)
- qemu: domain: Remove unused qemuDomainDiskNodeFormatLookup (rhbz#1207659)
- qemu: checkpoint: Introduce helper to find checkpoint disk definition in parents (rhbz#1207659)
- qemu: checkpoint: Extract calculation of bitmap merging for checkpoint deletion (rhbz#1207659)
- qemu: snapshot: go through cleanup on error (rhbz#1524278)
- util: hash: Use g_new0 for allocating hash internals (rhbz#1793263)
- conf: domain: Remove checking of return value of virHashCreateFull (rhbz#1793263)
- Remove checking of return value of virHashNew (rhbz#1793263)
- qemuMigrationCookieAddNBD: Exit early if there are no disks (rhbz#1793263)
- qemuMigrationCookieNBD: Extract embedded struct (rhbz#1793263)
- qemuMigrationCookieAddNBD: Use glib memory allocators (rhbz#1793263)
- qemuMigrationCookieAddNBD: Move monitor call out of the loop (rhbz#1793263)
- qemuMigrationCookieAddNBD: Use virHashNew and automatic freeing of virHashTablePtr (rhbz#1793263)
- qemuMigrationCookieAddNBD: Remove 'ret' variable and 'cleanup' label (rhbz#1793263)
- qemuMigrationCookieAddNBD: Fix filling of 'capacity' when blockdev is used (rhbz#1793263)
- tests: qemublock: Add test for checkpoint deletion bitmap merge (rhbz#1207659)
- tests: qemublock: Add few more test cases for checkpoint deletion (rhbz#1207659)
- tests: qemublock: Add synthetic snapshot+checkpoint test data (rhbz#1207659)
- qemu: checkpoint: Introduce support for deleting checkpoints accross snapshots (rhbz#1207659)
- tests: qemublock: Add checkpoint deletion test for deep backing chain (rhbz#1207659)
- tests: qemublock: Add checkpoint deletion tests for some special cases (rhbz#1207659)
- qemu: checkpoint: Track and relabel images for bitmap merging (rhbz#1207659)
- qemu: block: Extract calls of qemuBlockGetNamedNodeData into a helper function (rhbz#1207659)
- util: json: Introduce virJSONValueArrayConcat (rhbz#1207659)
- virJSONValueNewArray: Use g_new0 to allocate and remove NULL checks from callers (rhbz#1207659)
- virhash: Fix the expectations of virHashKeyEqual implementations (rhbz#1207659)
- virHashAddOrUpdateEntry: Simplify allocation of new entry (rhbz#1207659)
- qemu: blockjob: Store 'jobflags' with block job data (rhbz#1207659)
- qemu: blockjob: Store 'flags' for all the block job types (rhbz#1207659)
- qemu: block: Add validator for bitmap chains accross backing chains (rhbz#1207659)
- tests: qemublocktest: Add another synthetic test case for broken bitmaps (rhbz#1207659)
- qemu: block: Introduce function to calculate bitmap handling for block-copy (rhbz#1207659)
- tests: qemublock: Add tests for qemuBlockBitmapsHandleBlockcopy (rhbz#1207659)
- qemuDomainBlockPivot: Copy bitmaps backing checkpoints for virDomainBlockCopy (rhbz#1207659)
- docs: domaincaps: Mention VIR_DOMAIN_UNDEFINE_CHECKPOINTS_METADATA (rhbz#1207659)

* Tue Feb  4 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-3
- cpu.c: Check properly for virCapabilitiesGetNodeInfo() retval (rhbz#1794691)
- qemu_conf: Avoid dereferencing NULL in virQEMUDriverGetHost{NUMACaps, CPU} (rhbz#1794691)
- qemu_capabilities: Rework domain caps cache (rhbz#1794691)
- conf: add support for specifying CPU "dies" parameter (rhbz#1785211, rhbz#1785207)
- conf: remove unused virCapabilitiesSetHostCPU method (rhbz#1785211, rhbz#1785207)
- qemu: add support for specifying CPU "dies" topology parameter (rhbz#1785207)
- hostcpu: add support for reporting die_id in NUMA topology (rhbz#1785211)
- tests: add host CPU data files for validating die_id (rhbz#1785211, rhbz#1785207)
- qemu: add capabilities flag for failover feature (rhbz#1693587)
- conf: parse/format <teaming> subelement of <interface> (rhbz#1693587)
- qemu: support interface <teaming> functionality (rhbz#1693587)
- qemu: allow migration with assigned PCI hostdev if <teaming> is set (rhbz#1693587)
- qemu: add wait-unplug to qemu migration status enum (rhbz#1693587)
- docs: document <interface> subelement <teaming> (rhbz#1693587)

* Tue Jan 21 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-2
- qemuDomainSaveImageStartVM: Use VIR_AUTOCLOSE for @intermediatefd (rhbz#1718707)
- qemuDomainSaveImageStartVM: Use g_autoptr() for virCommand (rhbz#1718707)
- qemu: Use g_autoptr() for qemuDomainSaveCookie (rhbz#1718707)
- qemu: Stop domain on failed restore (rhbz#1718707)
- qemu: Don't emit SUSPENDED_POSTCOPY event on destination (rhbz#1791458)
- util: storagefile: Properly set transport type when parsing NBD strings (rhbz#1791614)
- tests: virstorage: Add tests for NBD URI style syntax over UNIX (rhbz#1791614)
- qemu: end the agent job in qemuDomainSetTimeAgent (rhbz#1792723)

* Wed Jan 15 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-1
- Rebased to libvirt-6.0.0 (rhbz#1772045)
- The rebase also fixes the following bugs:
    rhbz#1711789, rhbz#1717396, rhbz#1778058, rhbz#1008350, rhbz#1610207
    rhbz#1746981, rhbz#1776949, rhbz#1780154, rhbz#1781079, rhbz#1783411
    rhbz#1784345, rhbz#1788850, rhbz#1788898, rhbz#1789310, rhbz#1790733

* Tue Dec 17 2019 Jiri Denemark <jdenemar@redhat.com> - 5.10.0-2
- qemu: driver: Use appropriate job name when setting blockjob speed (rhbz#1780497)

* Tue Dec  3 2019 Jiri Denemark <jdenemar@redhat.com> - 5.10.0-1
- Rebased to libvirt-5.10.0 (rhbz#1772045)
- The rebase also fixes the following bugs:
    rhbz#760547, rhbz#1171569, rhbz#1371022, rhbz#1375855, rhbz#1405537
    rhbz#1451398, rhbz#1465810, rhbz#1518998, rhbz#1518999, rhbz#1582202
    rhbz#1598162, rhbz#1609654, rhbz#1614740, rhbz#1623877, rhbz#1662024
    rhbz#1668139, rhbz#1705426, rhbz#1718255, rhbz#1741121, rhbz#1774375
    rhbz#1777094, rhbz#1777230, rhbz#1778014, rhbz#1778570

* Thu Nov 21 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-4
- libvirt-<module>: Check caller-provided buffers to be NULL with size > 0 (rhbz#1772842)

* Wed Nov 20 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-3
- cpu_map: Ship arm_features.xml (rhbz#1707897)

* Thu Nov 14 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-2
- tests: Update capabilities for QEMU 4.2.0 on aarch64 (rhbz#1707897)
- qemu: Rename virQEMUCapsObjectPropsMaxX86CPU (rhbz#1707897)
- qemu: Introduce QEMU_CAPS_ARM_MAX_CPU (rhbz#1707897)
- qemu: Query max-arm-cpu properties (rhbz#1707897)
- qemu: Update query-cpu-model-expansion check (rhbz#1707897)
- qemu: Perform full expansion on ARM (rhbz#1707897)
- cpu_map: Introduce ARM CPU features (rhbz#1707897)
- cpu: Validate ARM CPU features (rhbz#1707897)
- qemu: Validate ARM CPU features (rhbz#1707897)
- tests: Introduce tests for ARM CPU features (rhbz#1707897)

* Wed Nov 13 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-1
- Rebased to libvirt-5.9.0 (rhbz#1772045)
- The rebase also fixes the following bugs:
    rhbz#1515831, rhbz#1704761, rhbz#1704763, rhbz#1704764, rhbz#1704779
    rhbz#1705514, rhbz#1705516, rhbz#1705517, rhbz#1705519, rhbz#1705520
    rhbz#1733044, rhbz#1733092, rhbz#1524278, rhbz#1662588, rhbz#1720612
    rhbz#1733163, rhbz#1743177, rhbz#1744924, rhbz#1745815, rhbz#1746274
    rhbz#1746617, rhbz#1747826, rhbz#1751461, rhbz#1751580, rhbz#1619625
    rhbz#1755803

* Mon Oct 21 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-7
- qemu_blockjob: Remove secdriver metadata for whole backing chain on job completion (rhbz#1741456)
- qemu_driver: Fix comment of qemuStateCleanup() (rhbz#1755303)
- driver: Introduce virDriverShouldAutostart() (rhbz#1755303)
- lib: autostart objects exactly once (rhbz#1755303)
- Revert "src: Document autostart for session demon" (rhbz#1755303)
- security: Pass @migrated to virSecurityManagerSetAllLabel (rhbz#1740024)
- security: Rename virSecurityManagerGetDriver() to virSecurityManagerGetVirtDriver() (rhbz#1740024)
- security: Introduce virSecurityManagerGetDriver() (rhbz#1740024)
- security_stack: Turn list of nested drivers into a doubly linked list (rhbz#1740024)
- security_stack: Perform rollback if one of stacked drivers fails (rhbz#1740024)
- util: new function virNetDevMacVLanIsMacvtap() (rhbz#1723367)
- util: make a couple virNetDevMacVlan*() functions public (rhbz#1723367)
- qemu: reorganize qemuInterfaceEthernetConnect() (rhbz#1723367)
- conf: use virXMLFormatElement for interface <target> (rhbz#1723367)
- conf: new "managed" attribute for target dev of <interface type='ethernet'> (rhbz#1723367)
- qemu: support unmanaged target tap dev for <interface type='ethernet'> (rhbz#1723367)
- qemu: support unmanaged macvtap devices with <interface type='ethernet'> (rhbz#1723367)

* Thu Sep 19 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-6
- remote: fix registration of TLS socket (rhbz#1752837)

* Mon Sep 16 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-5
- vircgroupv2: fix setting cpu.max period (rhbz#1749247)

* Wed Sep  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-4
- src: security: Replace bitwise OR with logical OR (rhbz#1740024)
- security_util: Use more VIR_AUTOFREE() (rhbz#1740024)
- security_util: Document virSecurityMoveRememberedLabel (rhbz#1740024)
- security: Don't increase XATTRs refcounter on failure (rhbz#1740024)
- util: Introduce virhostuptime (rhbz#1741140)
- security_util: Remove stale XATTRs (rhbz#1741140)
- security_util: verify xattrs only if ref is present (rhbz#1741140)
- virSecuritySELinuxSetFileconImpl: Drop @optional argument (rhbz#1740506)
- security_selinux: Drop virSecuritySELinuxSetFileconOptional() (rhbz#1740506)
- security_selinux: Drop @optional from _virSecuritySELinuxContextItem (rhbz#1740506)
- security_selinux: Drop virSecuritySELinuxSetFileconHelper (rhbz#1740506)
- security_selinux: Play nicely with network FS that only emulates SELinux (rhbz#1740506)
- qemu_blockjob: Print image path on failed security metadata move too (rhbz#1741456)
- qemu_blockjob: Remove secdriver metadata more frequently (rhbz#1741456)
- vircgroupv2: fix abort in VIR_AUTOFREE (rhbz#1747482)

* Fri Aug 30 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-3
- vircgroupv2: fix parsing multiple values in single file (rhbz#1734353)
- vircgroupv2: fix virCgroupV2GetCpuCfsQuota for "max" value (rhbz#1735740)
- network: fix ability to use openvswitch with vlans (rhbz#1739554)
- remote: use Wants instead of Requires for libvirtd sockets (rhbz#1741403)
- remote: move timeout arg into sysconf file (rhbz#1741403)
- remote: forbid the --listen arg when systemd socket activation (rhbz#1741403)
- rpm: don't enable socket activation in upgrade if --listen present (rhbz#1741403)
- qemuBuildHotpluggableCPUProps: use VIR_RETURN_PTR (rhbz#1741658)
- qemu: Extract and store vCPU properties as qemu returned them (rhbz#1741658)
- qemu: command: Use all vCPU properties when creating args for vCPU hotplug (rhbz#1741658)
- qemu: alias: Generate 'qomName' of disk with useraliases (rhbz#1741838)

* Mon Aug 19 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-2
- Revert "tpm: Check TPM XML device configuration changes after edit" (rhbz#1739338)
- qemu: Clarify error message in qemuMigrationSrcIsSafe (rhbz#1660575)
- qemu: Check for drop-cache capability (rhbz#1660575)
- qemu: Allow migration with disk cache on (rhbz#1660575)
- qemu: Pass qemuCaps to qemuDomainDefCopy (rhbz#1741796)
- qemu: Pass qemuCaps to qemuDomainDefFormatBufInternal (rhbz#1741796)
- qemu: Pass qemuCaps to qemuDomainSaveImageOpen (rhbz#1741796)
- qemu: Pass qemuCaps to qemuMigrationAnyPrepareDef (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefParseString (rhbz#1741796)
- qemu: Pass qemuCaps to qemuMigrationCookieXMLParse (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefCopy (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefPostParse (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefParseNode (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDeviceDefPostParse (rhbz#1741796)
- qemu: Fix crash on incoming migration (rhbz#1741796)
- network: fix crash during cleanup from failure to allocate port (rhbz#1741390)
- network: replace virSaveLastError() with virErrorPreserveLast() (rhbz#1741390)
- access: fix incorrect addition to virAccessPermNetwork (rhbz#1741428)
- util: allow tap-based guest interfaces to have MAC address prefix 0xFE (rhbz#1743349)

* Tue Aug  6 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-1
- Rebased to libvirt-5.6.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1643404, rhbz#1721375, rhbz#1724065, rhbz#1726609, rhbz#1726643
    rhbz#1727013, rhbz#1727866, rhbz#1729022, rhbz#1731332

* Fri Jul 26 2019 Jiri Denemark <jdenemar@redhat.com> - 5.5.0-2
- vircgroup: fix cgroups v2 controllers detection (rhbz#1513930)
- vircgroupv2: store enabled controllers (rhbz#1513930)

* Wed Jul  3 2019 Jiri Denemark <jdenemar@redhat.com> - 5.5.0-1
- Rebased to libvirt-5.5.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1426162, rhbz#1513930, rhbz#1598657, rhbz#1717768, rhbz#1720517
    rhbz#1720519, rhbz#1720522, rhbz#1720524, rhbz#1722360, rhbz#1723633

* Thu Jun 27 2019 Pavel Hrdina <phrdina@redhat.com> - 5.4.0-2
- RHEL: spec: Disable gluster on i686 (rhbz#1724445)
- rpc: virnetlibsshsession: update deprecated functions (rhbz#1724678)

* Tue Jun  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.4.0-1
- Rebased to libvirt-5.4.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1580229, rhbz#1628475, rhbz#1702758, rhbz#1707708, rhbz#1716260
    rhbz#1716261, rhbz#1716262, rhbz#1716263

* Tue May  7 2019 Jiri Denemark <jdenemar@redhat.com> - 5.3.0-1
- Rebased to libvirt-5.3.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1578741, rhbz#1602418, rhbz#1680304, rhbz#1690240, rhbz#1292102
    rhbz#1623389, rhbz#1658504, rhbz#1689165, rhbz#1689815, rhbz#1692926
    rhbz#1217444, rhbz#1564270, rhbz#1580229, rhbz#1697676

* Fri Mar 15 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-7
- qemu: Set job statsType for external memory snapshot (rhbz#1688774)

* Wed Mar  6 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-6
- qemu: Don't set migration caps when changing postcopy bandwidth (rhbz#1336709)

* Fri Mar  1 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-5
- qemu: fix i6300esb watchdog hotplug on Q35 (rhbz#1666559)

* Tue Feb 26 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-4
- RHEL: util: fix typo in iptables --delete command (rhbz#1679119)

* Mon Feb 18 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-3
- vshtabletest: indent strings with expected output (rhbz#1676354)
- vsh-table: allow empty columns (rhbz#1676354)
- virsh: introduce ninfos variable in cmdDomFSInfo (rhbz#1676354)
- virsh: rename ret to rc in cmdDomFSInfo (rhbz#1676354)
- virsh: do not access uninitialized memory in cmdDomFSInfo (rhbz#1676354)
- virsh: introduce 'ret' in cmdDomFSInfo (rhbz#1676354)
- virsh: do not report error on zero filesystems in cmdDomFSInfo (rhbz#1676354)
- virsh: use virBufferTrim in cmdDomFSInfo (rhbz#1676354)
- virsh: allow empty targets in cmdDomFSInfo (rhbz#1676354)
- util: fix memory leak in virFirewallDInterfaceSetZone() (rhbz#1672340)
- internal: introduce a family of NULLSTR macros (rhbz#1662849)
- virsh: fix snapshot list --parent (rhbz#1662849)
- network: explicitly allow icmp/icmpv6 in libvirt zonefile (rhbz#1672340)

* Fri Feb  8 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-2
- RHEL: qemu: Fix crash trying to use iSCSI hostdev (rhbz#1669966)
- docs: Drop /dev/net/tun from the list of shared devices (rhbz#1671791)
- qemu: conf: Remove /dev/sev from the default cgroup device acl list (rhbz#1671791)
- qemu: cgroup: Expose /dev/sev/ only to domains that require SEV (rhbz#1671791)
- qemu: domain: Add /dev/sev into the domain mount namespace selectively (rhbz#1671791)
- security: dac: Relabel /dev/sev in the namespace (rhbz#1671791)
- qemu: caps: Use CAP_DAC_OVERRIDE for probing to avoid permission issues (rhbz#1671791)
- qemu: caps: Don't try to ask for CAP_DAC_OVERRIDE if non-root (rhbz#1671791)
- qemu: command: Don't skip 'readonly' and throttling info for empty drive (rhbz#1672259)
- Revert "RHEL: network: regain guest network connectivity after firewalld switch to nftables" (rhbz#1672340)
- configure: change HAVE_FIREWALLD to WITH_FIREWALLD (rhbz#1672340)
- util: move all firewalld-specific stuff into its own files (rhbz#1672340)
- util: new virFirewallD APIs + docs (rhbz#1672340)
- configure: selectively install a firewalld 'libvirt' zone (rhbz#1672340)
- network: set firewalld zone of bridges to "libvirt" zone when appropriate (rhbz#1672340)
- network: allow configuring firewalld zone for virtual network bridge device (rhbz#1672340)
- util: remove test code accidentally committed to virFirewallDZoneExists (rhbz#1672340)
- qemu: Use C99 initializers for qemuMigrationParamsTPMap (rhbz#1336709)
- qemu: Add optional unit to qemuMigrationParamsTPMapItem (rhbz#1336709)
- qemu: Rework qemuDomainMigrateSetMaxSpeed (rhbz#1336709)
- qemu: Make migration params usable outside migration (rhbz#1336709)
- Public API for post-copy migration bandwidth (rhbz#1336709)
- qemu: Implement VIR_MIGRATE_PARAM_BANDWIDTH_POSTCOPY (rhbz#1336709)
- qemu: Implement VIR_DOMAIN_MIGRATE_MAX_SPEED_POSTCOPY flag (rhbz#1336709)
- virsh: Add support for setting post-copy migration bandwidth (rhbz#1336709)

* Fri Jan 25 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-1
- Rebased to libvirt-5.0.0 (rhbz#1666130)
- The rebase also fixes the following bugs:
    rhbz#1597869, rhbz#1644567
- tests: qemuxml2argv: Add test case for empty CDROM with cache mode (rhbz#1668027)
- qemu: command: Don't format image properties for empty -drive (rhbz#1668027)

* Thu Dec  6 2018 Jiri Denemark <jdenemar@redhat.com> - 4.10.0-1
- Rebased to libvirt-4.10.0

* Tue Nov 20 2018 Jiri Denemark <jdenemar@redhat.com> - 4.9.0-1
- Rebased to libvirt-4.9.0
- RHEL: Fix virConnectGetMaxVcpus output (rhbz#1582222)
- RHEL: spec: Require python3-devel on RHEL-8 (rhbz#1518446)
- RHEL: network: regain guest network connectivity after firewalld switch to nftables (rhbz#1638864)

* Fri Nov  9 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-14
- storage: Remove secretPath from _virStorageBackendQemuImgInfo (rhbz#1645459)
- storage: Allow for inputvol to have any format for encryption (rhbz#1645459)
- storage: Allow inputvol to be encrypted (rhbz#1645459)
- access: Modify the VIR_ERR_ACCESS_DENIED to include driverName (rhbz#1631608)
- docs: Enhance polkit documentation to describe secondary connection (rhbz#1631608)
- qemu: Don't ignore resume events (rhbz#1634758, rhbz#1643338)

* Thu Nov  1 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-13
- Revert "spec: Temporarily drop gluster support" (rhbz#1599339)

* Wed Oct 17 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-12
- RHEL: Require firewalld-filesystem for firewalld rpm macros (rhbz#1639932)

* Tue Oct 16 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-11
- virfile: fix cast-align error (rhbz#1634782)
- virfiletest: Fix test name prefix for virFileInData test (rhbz#1634782)
- virfiletst: Test virFileIsSharedFS (rhbz#1634782)
- virFileIsSharedFSType: Detect direct mount points (rhbz#1634782)
- virfile: Rework virFileIsSharedFixFUSE (rhbz#1634782)
- RHEL: network: regain guest network connectivity after firewalld switch to nftables (rhbz#1638864)

* Mon Oct  8 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-10
- conf: Fix check for chardev source path (rhbz#1609723)
- tests: Reuse qemucapabilities data for qemucaps2xml (rhbz#1629862)
- tests: Add more tests to qemucaps2xml (rhbz#1629862)
- qemu: Drop QEMU_CAPS_ENABLE_KVM (rhbz#1629862)
- qemu: Avoid probing non-native binaries all the time (rhbz#1629862)
- qemu: Clarify QEMU_CAPS_KVM (rhbz#1629862)
- qemu: Don't check for /dev/kvm presence (rhbz#1629862)
- tests: Follow up on qemucaps2xmldata rename (rhbz#1629862)
- security: dac: also label listen UNIX sockets (rhbz#1634775)
- spec: Set correct TLS priority (rhbz#1632269)
- spec: Build ceph and gluster support everywhere (rhbz#1599546)
- virsh: Require explicit --domain for domxml-to-native (rhbz#1634769)
- virFileIsSharedFSType: Check for fuse.glusterfs too (rhbz#1634782)
- qemu: fix up permissions for pre-created UNIX sockets (rhbz#1634775)
- cpu_map: Add features for Icelake CPUs (rhbz#1527657, rhbz#1526625)
- cpu_map: Add Icelake CPU models (rhbz#1526625)
- qemu: Properly report VIR_DOMAIN_EVENT_RESUMED_FROM_SNAPSHOT (rhbz#1634758)
- qemu: Report more appropriate running reasons (rhbz#1634758)
- qemu: Pass running reason to RESUME event handler (rhbz#1634758)
- qemu: Map running reason to resume event detail (rhbz#1634758)
- qemu: Avoid duplicate resume events and state changes (rhbz#1634758)
- conf: qemu: add support for Hyper-V frequency MSRs (rhbz#1589702)
- conf: qemu: add support for Hyper-V reenlightenment notifications (rhbz#1589702)
- conf: qemu: add support for Hyper-V PV TLB flush (rhbz#1589702)

* Wed Sep  5 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-9
- RHEL: Fix virConnectGetMaxVcpus output (rhbz#1582222)
- storage: Add --shrink to qemu-img command when shrinking vol (rhbz#1622534)
- access: Fix nwfilter-binding ACL access API name generation (rhbz#1622540)
- conf: Add validation of input devices (rhbz#1591240)
- tests: qemu: Remove disk from graphics-vnc-tls (rhbz#1598167)
- tests: qemu: test more versions for graphics-vnc-tls (rhbz#1598167)
- qemu: vnc: switch to tls-creds-x509 (rhbz#1598167)
- qemu: mdev: Use vfio-pci 'display' property only with vfio-pci mdevs (rhbz#1624740)
- virDomainDefCompatibleDevice: Relax alias change check (rhbz#1603133)
- virDomainDetachDeviceFlags: Clarify update semantics (rhbz#1603133)
- virDomainNetDefCheckABIStability: Check for MTU change too (rhbz#1623158)
- RHEL: spec: Require python3-devel on RHEL-8 (rhbz#1518446)
- qemu: monitor: Remove qemuMonitorJSONExtractCPUArchInfo wrapper (rhbz#1598829)
- qemu: monitor: Use 'target' instead of 'arch' in reply of 'query-cpus-fast' (rhbz#1598829)

* Tue Aug 21 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-8
- tests: Add missing thread_siblings_list files (rhbz#1608479)
- util: Rewrite virHostCPUCountThreadSiblings() (rhbz#1608479)
- utils: Remove arbitrary limit on socket_id/core_id (rhbz#1608479)
- tests: Add linux-high-ids test (rhbz#1608479)
- qemu: hotplug: Fix asynchronous unplug of 'shmem' (rhbz#1618680)
- tests: rename hugepages to hugepages-default (rhbz#1615461)
- tests: extract hugepages-numa-default-dimm out of hugepages-numa (rhbz#1615461)
- tests: rename hugepages-numa into hugepages-numa-default (rhbz#1615461)
- tests: remove unnecessary XML elements from hugepages-numa-default (rhbz#1615461)
- tests: extract pages-discard out of hugepages-pages (rhbz#1615461)
- tests: rename hugepages-pages into hugepages-numa-nodeset (rhbz#1615461)
- tests: rename hugepages-pages2 into hugepages-numa-default-2M (rhbz#1615461)
- tests: extract pages-discard-hugepages out of hugepages-pages3 (rhbz#1615461)
- tests: rename hugepages-pages3 into hugepages-numa-nodeset-part (rhbz#1615461)
- tests: rename hugepages-pages4 into hugepages-numa-nodeset-nonexist (rhbz#1615461)
- tests: rename hugepages-pages5 into hugepages-default-2M (rhbz#1615461)
- tests: rename hugepages-pages6 into hugepages-default-system-size (rhbz#1615461)
- tests: rename hugepages-pages7 into pages-dimm-discard (rhbz#1615461)
- tests: rename hugepages-pages8 into hugepages-nodeset-nonexist (rhbz#1615461)
- tests: introduce hugepages-default-1G-nodeset-2M (rhbz#1615461)
- tests: introduce hugepages-nodeset (rhbz#1615461)
- conf: Move hugepage XML validation check out of qemu_command (rhbz#1615461)
- conf: Move hugepages validation out of XML parser (rhbz#1615461)
- conf: Introduce virDomainDefPostParseMemtune (rhbz#1615461)
- tests: sev: Test launch-security with specific QEMU version (rhbz#1619150)
- qemu: Fix probing of AMD SEV support (rhbz#1619150)
- qemu: caps: Format SEV platform data into qemuCaps cache (rhbz#1619150)
- conf: Parse guestfwd channel device info again (rhbz#1610072)

* Thu Aug 16 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-7
- qemu_migration: Avoid writing to freed memory (rhbz#1615854)

* Thu Aug  2 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-6
- qemu: Exempt video model 'none' from getting a PCI address on Q35
- conf: Fix a error msg typo in virDomainVideoDefValidate

* Tue Jul 31 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-5
- esx storage: Fix typo lsilogic -> lsiLogic
- networkGetDHCPLeases: Don't always report error if unable to read leases file
- nwfilter: Resolve SEGV for NWFilter Snoop processing
- qemu: Remove unused bypassSecurityDriver from qemuOpenFileAs
- qemuDomainSaveMemory: Don't enforce dynamicOwnership
- domain_nwfilter: Return early if net has no name in virDomainConfNWFilterTeardownImpl
- examples: Add clean-traffic-gateway into nwfilters

* Mon Jul 23 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-4
- qemu: hotplug: don't overwrite error message in qemuDomainAttachNetDevice
- qemu: hotplug: report error when changing rom enabled attr for net iface
- qemu: Fix setting global_period cputune element
- tests: qemucaps: Add test data for upcoming qemu 3.0.0
- qemu: capabilities: Add capability for werror/rerror for 'usb-device' frontend
- qemu: command: Move graphics iteration to its own function
- qemu: address: Handle all the video devices within a single loop
- conf: Introduce virDomainVideoDefClear helper
- conf: Introduce virDomainDefPostParseVideo helper
- qemu: validate: Enforce compile time switch type checking for videos
- tests: Add capabilities data for QEMU 2.11 x86_64
- tests: Update capabilities data for QEMU 3.0.0 x86_64
- qemu: qemuBuildHostdevCommandLine: Use a helper variable mdevsrc
- qemu: caps: Introduce a capability for egl-headless
- qemu: Introduce a new graphics display type 'headless'
- qemu: caps: Add vfio-pci.display capability
- conf: Introduce virDomainGraphicsDefHasOpenGL helper
- conf: Replace 'error' with 'cleanup' in virDomainHostdevDefParseXMLSubsys
- conf: Introduce new <hostdev> attribute 'display'
- qemu: command: Enable formatting vfio-pci.display option onto cmdline
- docs: Rephrase the mediated devices hostdev section a bit
- conf: Introduce new video type 'none'
- virt-xml-validate: Add schema for nwfilterbinding
- tools: Fix typo generating adapter_wwpn field
- src: Fix memory leak in virNWFilterBindingDispose

* Mon Jul 23 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-3
- qemu: hotplug: Do not try to add secret object for TLS if it does not exist
- qemu: monitor: Make qemuMonitorAddObject more robust against programming errors
- spec: Explicitly require matching libvirt-libs
- virDomainConfNWFilterInstantiate: initialize @xml to avoid random crash
- qemuProcessStartPRDaemonHook: Try to set NS iff domain was started with one
- qemuDomainValidateStorageSource: Relax PR validation
- virStoragePRDefFormat: Suppress path formatting for migratable XML
- qemu: Wire up PR_MANAGER_STATUS_CHANGED event
- qemu_monitor: Introduce qemuMonitorJSONGetPRManagerInfo
- qemu: Fetch pr-helper process info on reconnect
- qemu: Fix ATTRIBUTE_NONNULL for qemuMonitorAddObject
- virsh.pod: Fix a command name typo in nwfilter-binding-undefine
- docs: schema: Add missing <alias> to vsock device
- virnetdevtap: Don't crash on !ifname in virNetDevTapInterfaceStats
- tests: fix TLS handshake failure with TLS 1.3

* Mon Jul  9 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-2
- qemu: Add capability for the HTM pSeries feature
- conf: Parse and format the HTM pSeries feature
- qemu: Format the HTM pSeries feature
- qemu: hotplug: Don't access srcPriv when it's not allocated
- qemuDomainNestedJobAllowed: Allow QEMU_JOB_NONE
- src: Mention DEVICE_REMOVAL_FAILED event in virDomainDetachDeviceAlias docs
- virsh.pod: Drop --persistent for detach-device-alias
- qemu: don't use chardev FD passing with standalone args
- qemu: remove chardevStdioLogd param from vhostuser code path
- qemu: consolidate parameters of qemuBuildChrChardevStr into flags
- qemu: don't use chardev FD passing for vhostuser backend
- qemu: fix UNIX socket chardevs operating in client mode
- qemuDomainDeviceDefValidateNetwork: Check for range only if IP prefix set
- spec: Temporarily drop gluster support

* Tue Jul  3 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-1
- Rebased to libvirt-4.5.0

* Fri May 25 2018 Jiri Denemark <jdenemar@redhat.com> - 4.3.0-1
- Rebased to libvirt-4.3.0

* Wed Mar 21 2018 Daniel P. Berrangé <berrange@redhat.com> - 4.1.0-2
- Fix systemd macro argument with line continuations (rhbz#1558648)

* Mon Mar  5 2018 Daniel Berrange <berrange@redhat.com> - 4.1.0-1
- Rebase to version 4.1.0

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 19 2018 Daniel P. Berrange <berrange@redhat.com> - 4.0.0-1
- Rebase to version 4.0.0

* Wed Dec 20 2017 Cole Robinson <crobinso@redhat.com> - 3.10.0-2
- Rebuild for xen 4.10

* Tue Dec  5 2017 Daniel P. Berrange <berrange@redhat.com> - 3.10.0-1
- Rebase to version 3.10.0

* Fri Nov  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.9.0-1
- Rebase to version 3.9.0

* Wed Oct  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.8.0-1
- Rebase to version 3.8.0

* Mon Sep  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.7.0-1
- Rebase to version 3.7.0

* Wed Aug  2 2017 Daniel P. Berrange <berrange@redhat.com> - 3.6.0-1
- Rebase to version 3.6.0

* Sun Jul 30 2017 Florian Weimer <fweimer@redhat.com> - 3.5.0-4
- Rebuild with binutils fix for ppc64le (#1475636)

* Tue Jul 25 2017 Daniel P. Berrange <berrange@redhat.com> - 3.5.0-3
- Disabled RBD on i386, arm, ppc64 (rhbz #1474743)

* Mon Jul 17 2017 Cole Robinson <crobinso@redhat.com> - 3.5.0-2
- Rebuild for xen 4.9

* Thu Jul  6 2017 Daniel P. Berrange <berrange@redhat.com> - 3.5.0-1
- Rebase to version 3.5.0

* Fri Jun  2 2017 Daniel P. Berrange <berrange@redhat.com> - 3.4.0-1
- Rebase to version 3.4.0

* Mon May  8 2017 Daniel P. Berrange <berrange@redhat.com> - 3.3.0-1
- Rebase to version 3.3.0

* Mon Apr  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.2.0-1
- Rebase to version 3.2.0

* Fri Mar  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.1.0-1
- Rebase to version 3.1.0

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 19 2017 Daniel P. Berrange <berrange@redhat.com> - 3.0.0-1
- Rebase to version 3.0.0
